
package net.ericaro.neoevents.java.awt.dnd;

//GENERATED DO NOT EDIT

import java.lang.annotation.Annotation;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;

import net.ericaro.neoevents.AbstractEvent;

/**
 *  <p>This is a transparent {@link java.awt.dnd.DragSourceListener} that uses annotations to convert any objects into
 *  an DragSourceListener. </p>
 * 
 * Annotating methods of any object with the following annotations: 
 *
 * <ul><li>dragDropEnd</li>
<li>dragExit</li>
<li>dragEnter</li>
<li>dragOver</li>
<li>dropActionChanged</li>
</ul>
 *
 * will call those methods when the corresponding events is fired.
 * 
 * example
 * <p>
 * <pre>
 * public class MyController {
 *     
 *     ...
 *     
 *     Object source;
 * 
 *     ...
 * 
 *     source.addDragSourceListener(new DragSourceListener(this) );
 *     
 *     ...    
 *     
 *     &#64;DragSourceListener.dragDropEnd
 *     protected void go(){
 *     System.out.println("go! go! go!"); // called when source will trigger the DragSourceListener.dragDropEnd event
 *     }
 * 
 * }
 * 
 * methods can be either:
 * <ul>
 * <li>without parameters</li>
 * <li>without one parameter of any super type of the corresponding event type</li>
 * </ul>
 * 
 * </pre>
 * 
 * </p>
 * 
 *
 */
public class DragSourceListener extends AbstractEvent implements java.awt.dnd.DragSourceListener{

    /** Creates an instance of Interface java.awt.dnd.DragSourceListener that will forward every call to the target's methods annotated with:
     * <ul><li>dragDropEnd</li>
<li>dragExit</li>
<li>dragEnter</li>
<li>dragOver</li>
<li>dropActionChanged</li>
</ul>
     *
     * @param target the object that will receive events
     */
    public DragSourceListener(Object target) {
        super(target
            ,dragDropEnd.class
            ,dragExit.class
            ,dragEnter.class
            ,dragOver.class
            ,dropActionChanged.class

                
        );
    }
    
    
    /** Annotation to mark a method as a target for {@link java.awt.dnd.DragSourceListener.dragDropEnd()} calls  */
    @Retention(RetentionPolicy.RUNTIME) public static @interface dragDropEnd {}
    @Override public void dragDropEnd(java.awt.dnd.DragSourceDropEvent arg0) { fire(dragDropEnd.class, arg0); } 


    /** Annotation to mark a method as a target for {@link java.awt.dnd.DragSourceListener.dragExit()} calls  */
    @Retention(RetentionPolicy.RUNTIME) public static @interface dragExit {}
    @Override public void dragExit(java.awt.dnd.DragSourceEvent arg0) { fire(dragExit.class, arg0); } 


    /** Annotation to mark a method as a target for {@link java.awt.dnd.DragSourceListener.dragEnter()} calls  */
    @Retention(RetentionPolicy.RUNTIME) public static @interface dragEnter {}
    @Override public void dragEnter(java.awt.dnd.DragSourceDragEvent arg0) { fire(dragEnter.class, arg0); } 


    /** Annotation to mark a method as a target for {@link java.awt.dnd.DragSourceListener.dragOver()} calls  */
    @Retention(RetentionPolicy.RUNTIME) public static @interface dragOver {}
    @Override public void dragOver(java.awt.dnd.DragSourceDragEvent arg0) { fire(dragOver.class, arg0); } 


    /** Annotation to mark a method as a target for {@link java.awt.dnd.DragSourceListener.dropActionChanged()} calls  */
    @Retention(RetentionPolicy.RUNTIME) public static @interface dropActionChanged {}
    @Override public void dropActionChanged(java.awt.dnd.DragSourceDragEvent arg0) { fire(dropActionChanged.class, arg0); } 

    
    
}