
package net.ericaro.neoevents.java.awt.dnd;

//GENERATED DO NOT EDIT

import java.lang.annotation.Annotation;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;

import net.ericaro.neoevents.AbstractEvent;

/**
 *  <p>This is a transparent {@link java.awt.dnd.DropTargetListener} that uses annotations to convert any objects into
 *  an DropTargetListener. </p>
 * 
 * Annotating methods of any object with the following annotations: 
 *
 * <ul><li>dragExit</li>
<li>dragEnter</li>
<li>dragOver</li>
<li>drop</li>
<li>dropActionChanged</li>
</ul>
 *
 * will call those methods when the corresponding events is fired.
 * 
 * example
 * <p>
 * <pre>
 * public class MyController {
 *     
 *     ...
 *     
 *     Object source;
 * 
 *     ...
 * 
 *     source.addDropTargetListener(new DropTargetListener(this) );
 *     
 *     ...    
 *     
 *     &#64;DropTargetListener.dragExit
 *     protected void go(){
 *     System.out.println("go! go! go!"); // called when source will trigger the DropTargetListener.dragExit event
 *     }
 * 
 * }
 * 
 * methods can be either:
 * <ul>
 * <li>without parameters</li>
 * <li>without one parameter of any super type of the corresponding event type</li>
 * </ul>
 * 
 * </pre>
 * 
 * </p>
 * 
 *
 */
public class DropTargetListener extends AbstractEvent implements java.awt.dnd.DropTargetListener{

    /** Creates an instance of Interface java.awt.dnd.DropTargetListener that will forward every call to the target's methods annotated with:
     * <ul><li>dragExit</li>
<li>dragEnter</li>
<li>dragOver</li>
<li>drop</li>
<li>dropActionChanged</li>
</ul>
     *
     * @param target the object that will receive events
     */
    public DropTargetListener(Object target) {
        super(target
            ,dragExit.class
            ,dragEnter.class
            ,dragOver.class
            ,drop.class
            ,dropActionChanged.class

                
        );
    }
    
    
    /** Annotation to mark a method as a target for {@link java.awt.dnd.DropTargetListener.dragExit()} calls  */
    @Retention(RetentionPolicy.RUNTIME) public static @interface dragExit {}
    @Override public void dragExit(java.awt.dnd.DropTargetEvent arg0) { fire(dragExit.class, arg0); } 


    /** Annotation to mark a method as a target for {@link java.awt.dnd.DropTargetListener.dragEnter()} calls  */
    @Retention(RetentionPolicy.RUNTIME) public static @interface dragEnter {}
    @Override public void dragEnter(java.awt.dnd.DropTargetDragEvent arg0) { fire(dragEnter.class, arg0); } 


    /** Annotation to mark a method as a target for {@link java.awt.dnd.DropTargetListener.dragOver()} calls  */
    @Retention(RetentionPolicy.RUNTIME) public static @interface dragOver {}
    @Override public void dragOver(java.awt.dnd.DropTargetDragEvent arg0) { fire(dragOver.class, arg0); } 


    /** Annotation to mark a method as a target for {@link java.awt.dnd.DropTargetListener.drop()} calls  */
    @Retention(RetentionPolicy.RUNTIME) public static @interface drop {}
    @Override public void drop(java.awt.dnd.DropTargetDropEvent arg0) { fire(drop.class, arg0); } 


    /** Annotation to mark a method as a target for {@link java.awt.dnd.DropTargetListener.dropActionChanged()} calls  */
    @Retention(RetentionPolicy.RUNTIME) public static @interface dropActionChanged {}
    @Override public void dropActionChanged(java.awt.dnd.DropTargetDragEvent arg0) { fire(dropActionChanged.class, arg0); } 

    
    
}