
package net.ericaro.neoevents.java.awt.event;

//GENERATED DO NOT EDIT

import java.lang.annotation.Annotation;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;

import net.ericaro.neoevents.AbstractEvent;

/**
 *  <p>This is a transparent {@link java.awt.event.AWTEventListener} that uses annotations to convert any objects into
 *  an AWTEventListener. </p>
 * 
 * Annotating methods of any object with the following annotations: 
 *
 * <ul><li>eventDispatched</li>
</ul>
 *
 * will call those methods when the corresponding events is fired.
 * 
 * example
 * <p>
 * <pre>
 * public class MyController {
 *     
 *     ...
 *     
 *     Object source;
 * 
 *     ...
 * 
 *     source.addAWTEventListener(new AWTEventListener(this) );
 *     
 *     ...    
 *     
 *     &#64;AWTEventListener.eventDispatched
 *     protected void go(){
 *     System.out.println("go! go! go!"); // called when source will trigger the AWTEventListener.eventDispatched event
 *     }
 * 
 * }
 * 
 * methods can be either:
 * <ul>
 * <li>without parameters</li>
 * <li>without one parameter of any super type of the corresponding event type</li>
 * </ul>
 * 
 * </pre>
 * 
 * </p>
 * 
 *
 */
public class AWTEventListener extends AbstractEvent implements java.awt.event.AWTEventListener{

    /** Creates an instance of Interface java.awt.event.AWTEventListener that will forward every call to the target's methods annotated with:
     * <ul><li>eventDispatched</li>
</ul>
     *
     * @param target the object that will receive events
     */
    public AWTEventListener(Object target) {
        super(target
            ,eventDispatched.class

                
        );
    }
    
    
    /** Annotation to mark a method as a target for {@link java.awt.event.AWTEventListener.eventDispatched()} calls  */
    @Retention(RetentionPolicy.RUNTIME) public static @interface eventDispatched {}
    @Override public void eventDispatched(java.awt.AWTEvent arg0) { fire(eventDispatched.class, arg0); } 

    
    
}