
package net.ericaro.neoevents.java.awt.event;

//GENERATED DO NOT EDIT

import java.lang.annotation.Annotation;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;

import net.ericaro.neoevents.AbstractEvent;

/**
 *  <p>This is a transparent {@link java.awt.event.ActionListener} that uses annotations to convert any objects into
 *  an ActionListener. </p>
 * 
 * Annotating methods of any object with the following annotations: 
 *
 * <ul><li>actionPerformed</li>
</ul>
 *
 * will call those methods when the corresponding events is fired.
 * 
 * example
 * <p>
 * <pre>
 * public class MyController {
 *     
 *     ...
 *     
 *     Object source;
 * 
 *     ...
 * 
 *     source.addActionListener(new ActionListener(this) );
 *     
 *     ...    
 *     
 *     &#64;ActionListener.actionPerformed
 *     protected void go(){
 *     System.out.println("go! go! go!"); // called when source will trigger the ActionListener.actionPerformed event
 *     }
 * 
 * }
 * 
 * methods can be either:
 * <ul>
 * <li>without parameters</li>
 * <li>without one parameter of any super type of the corresponding event type</li>
 * </ul>
 * 
 * </pre>
 * 
 * </p>
 * 
 *
 */
public class ActionListener extends AbstractEvent implements java.awt.event.ActionListener{

    /** Creates an instance of Interface java.awt.event.ActionListener that will forward every call to the target's methods annotated with:
     * <ul><li>actionPerformed</li>
</ul>
     *
     * @param target the object that will receive events
     */
    public ActionListener(Object target) {
        super(target
            ,actionPerformed.class

                
        );
    }
    
    
    /** Annotation to mark a method as a target for {@link java.awt.event.ActionListener.actionPerformed()} calls  */
    @Retention(RetentionPolicy.RUNTIME) public static @interface actionPerformed {}
    @Override public void actionPerformed(java.awt.event.ActionEvent arg0) { fire(actionPerformed.class, arg0); } 

    
    
}