
package net.ericaro.neoevents.java.awt.event;

//GENERATED DO NOT EDIT

import java.lang.annotation.Annotation;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;

import net.ericaro.neoevents.AbstractEvent;

/**
 *  <p>This is a transparent {@link java.awt.event.ComponentListener} that uses annotations to convert any objects into
 *  an ComponentListener. </p>
 * 
 * Annotating methods of any object with the following annotations: 
 *
 * <ul><li>componentHidden</li>
<li>componentMoved</li>
<li>componentResized</li>
<li>componentShown</li>
</ul>
 *
 * will call those methods when the corresponding events is fired.
 * 
 * example
 * <p>
 * <pre>
 * public class MyController {
 *     
 *     ...
 *     
 *     Object source;
 * 
 *     ...
 * 
 *     source.addComponentListener(new ComponentListener(this) );
 *     
 *     ...    
 *     
 *     &#64;ComponentListener.componentHidden
 *     protected void go(){
 *     System.out.println("go! go! go!"); // called when source will trigger the ComponentListener.componentHidden event
 *     }
 * 
 * }
 * 
 * methods can be either:
 * <ul>
 * <li>without parameters</li>
 * <li>without one parameter of any super type of the corresponding event type</li>
 * </ul>
 * 
 * </pre>
 * 
 * </p>
 * 
 *
 */
public class ComponentListener extends AbstractEvent implements java.awt.event.ComponentListener{

    /** Creates an instance of Interface java.awt.event.ComponentListener that will forward every call to the target's methods annotated with:
     * <ul><li>componentHidden</li>
<li>componentMoved</li>
<li>componentResized</li>
<li>componentShown</li>
</ul>
     *
     * @param target the object that will receive events
     */
    public ComponentListener(Object target) {
        super(target
            ,componentHidden.class
            ,componentMoved.class
            ,componentResized.class
            ,componentShown.class

                
        );
    }
    
    
    /** Annotation to mark a method as a target for {@link java.awt.event.ComponentListener.componentHidden()} calls  */
    @Retention(RetentionPolicy.RUNTIME) public static @interface componentHidden {}
    @Override public void componentHidden(java.awt.event.ComponentEvent arg0) { fire(componentHidden.class, arg0); } 


    /** Annotation to mark a method as a target for {@link java.awt.event.ComponentListener.componentMoved()} calls  */
    @Retention(RetentionPolicy.RUNTIME) public static @interface componentMoved {}
    @Override public void componentMoved(java.awt.event.ComponentEvent arg0) { fire(componentMoved.class, arg0); } 


    /** Annotation to mark a method as a target for {@link java.awt.event.ComponentListener.componentResized()} calls  */
    @Retention(RetentionPolicy.RUNTIME) public static @interface componentResized {}
    @Override public void componentResized(java.awt.event.ComponentEvent arg0) { fire(componentResized.class, arg0); } 


    /** Annotation to mark a method as a target for {@link java.awt.event.ComponentListener.componentShown()} calls  */
    @Retention(RetentionPolicy.RUNTIME) public static @interface componentShown {}
    @Override public void componentShown(java.awt.event.ComponentEvent arg0) { fire(componentShown.class, arg0); } 

    
    
}