
package net.ericaro.neoevents.java.awt.event;

//GENERATED DO NOT EDIT

import java.lang.annotation.Annotation;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;

import net.ericaro.neoevents.AbstractEvent;

/**
 *  <p>This is a transparent {@link java.awt.event.ContainerListener} that uses annotations to convert any objects into
 *  an ContainerListener. </p>
 * 
 * Annotating methods of any object with the following annotations: 
 *
 * <ul><li>componentAdded</li>
<li>componentRemoved</li>
</ul>
 *
 * will call those methods when the corresponding events is fired.
 * 
 * example
 * <p>
 * <pre>
 * public class MyController {
 *     
 *     ...
 *     
 *     Object source;
 * 
 *     ...
 * 
 *     source.addContainerListener(new ContainerListener(this) );
 *     
 *     ...    
 *     
 *     &#64;ContainerListener.componentAdded
 *     protected void go(){
 *     System.out.println("go! go! go!"); // called when source will trigger the ContainerListener.componentAdded event
 *     }
 * 
 * }
 * 
 * methods can be either:
 * <ul>
 * <li>without parameters</li>
 * <li>without one parameter of any super type of the corresponding event type</li>
 * </ul>
 * 
 * </pre>
 * 
 * </p>
 * 
 *
 */
public class ContainerListener extends AbstractEvent implements java.awt.event.ContainerListener{

    /** Creates an instance of Interface java.awt.event.ContainerListener that will forward every call to the target's methods annotated with:
     * <ul><li>componentAdded</li>
<li>componentRemoved</li>
</ul>
     *
     * @param target the object that will receive events
     */
    public ContainerListener(Object target) {
        super(target
            ,componentAdded.class
            ,componentRemoved.class

                
        );
    }
    
    
    /** Annotation to mark a method as a target for {@link java.awt.event.ContainerListener.componentAdded()} calls  */
    @Retention(RetentionPolicy.RUNTIME) public static @interface componentAdded {}
    @Override public void componentAdded(java.awt.event.ContainerEvent arg0) { fire(componentAdded.class, arg0); } 


    /** Annotation to mark a method as a target for {@link java.awt.event.ContainerListener.componentRemoved()} calls  */
    @Retention(RetentionPolicy.RUNTIME) public static @interface componentRemoved {}
    @Override public void componentRemoved(java.awt.event.ContainerEvent arg0) { fire(componentRemoved.class, arg0); } 

    
    
}