
package net.ericaro.neoevents.java.awt.event;

//GENERATED DO NOT EDIT

import java.lang.annotation.Annotation;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;

import net.ericaro.neoevents.AbstractEvent;

/**
 *  <p>This is a transparent {@link java.awt.event.FocusListener} that uses annotations to convert any objects into
 *  an FocusListener. </p>
 * 
 * Annotating methods of any object with the following annotations: 
 *
 * <ul><li>focusGained</li>
<li>focusLost</li>
</ul>
 *
 * will call those methods when the corresponding events is fired.
 * 
 * example
 * <p>
 * <pre>
 * public class MyController {
 *     
 *     ...
 *     
 *     Object source;
 * 
 *     ...
 * 
 *     source.addFocusListener(new FocusListener(this) );
 *     
 *     ...    
 *     
 *     &#64;FocusListener.focusGained
 *     protected void go(){
 *     System.out.println("go! go! go!"); // called when source will trigger the FocusListener.focusGained event
 *     }
 * 
 * }
 * 
 * methods can be either:
 * <ul>
 * <li>without parameters</li>
 * <li>without one parameter of any super type of the corresponding event type</li>
 * </ul>
 * 
 * </pre>
 * 
 * </p>
 * 
 *
 */
public class FocusListener extends AbstractEvent implements java.awt.event.FocusListener{

    /** Creates an instance of Interface java.awt.event.FocusListener that will forward every call to the target's methods annotated with:
     * <ul><li>focusGained</li>
<li>focusLost</li>
</ul>
     *
     * @param target the object that will receive events
     */
    public FocusListener(Object target) {
        super(target
            ,focusGained.class
            ,focusLost.class

                
        );
    }
    
    
    /** Annotation to mark a method as a target for {@link java.awt.event.FocusListener.focusGained()} calls  */
    @Retention(RetentionPolicy.RUNTIME) public static @interface focusGained {}
    @Override public void focusGained(java.awt.event.FocusEvent arg0) { fire(focusGained.class, arg0); } 


    /** Annotation to mark a method as a target for {@link java.awt.event.FocusListener.focusLost()} calls  */
    @Retention(RetentionPolicy.RUNTIME) public static @interface focusLost {}
    @Override public void focusLost(java.awt.event.FocusEvent arg0) { fire(focusLost.class, arg0); } 

    
    
}