
package net.ericaro.neoevents.java.awt.event;

//GENERATED DO NOT EDIT

import java.lang.annotation.Annotation;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;

import net.ericaro.neoevents.AbstractEvent;

/**
 *  <p>This is a transparent {@link java.awt.event.HierarchyBoundsListener} that uses annotations to convert any objects into
 *  an HierarchyBoundsListener. </p>
 * 
 * Annotating methods of any object with the following annotations: 
 *
 * <ul><li>ancestorMoved</li>
<li>ancestorResized</li>
</ul>
 *
 * will call those methods when the corresponding events is fired.
 * 
 * example
 * <p>
 * <pre>
 * public class MyController {
 *     
 *     ...
 *     
 *     Object source;
 * 
 *     ...
 * 
 *     source.addHierarchyBoundsListener(new HierarchyBoundsListener(this) );
 *     
 *     ...    
 *     
 *     &#64;HierarchyBoundsListener.ancestorMoved
 *     protected void go(){
 *     System.out.println("go! go! go!"); // called when source will trigger the HierarchyBoundsListener.ancestorMoved event
 *     }
 * 
 * }
 * 
 * methods can be either:
 * <ul>
 * <li>without parameters</li>
 * <li>without one parameter of any super type of the corresponding event type</li>
 * </ul>
 * 
 * </pre>
 * 
 * </p>
 * 
 *
 */
public class HierarchyBoundsListener extends AbstractEvent implements java.awt.event.HierarchyBoundsListener{

    /** Creates an instance of Interface java.awt.event.HierarchyBoundsListener that will forward every call to the target's methods annotated with:
     * <ul><li>ancestorMoved</li>
<li>ancestorResized</li>
</ul>
     *
     * @param target the object that will receive events
     */
    public HierarchyBoundsListener(Object target) {
        super(target
            ,ancestorMoved.class
            ,ancestorResized.class

                
        );
    }
    
    
    /** Annotation to mark a method as a target for {@link java.awt.event.HierarchyBoundsListener.ancestorMoved()} calls  */
    @Retention(RetentionPolicy.RUNTIME) public static @interface ancestorMoved {}
    @Override public void ancestorMoved(java.awt.event.HierarchyEvent arg0) { fire(ancestorMoved.class, arg0); } 


    /** Annotation to mark a method as a target for {@link java.awt.event.HierarchyBoundsListener.ancestorResized()} calls  */
    @Retention(RetentionPolicy.RUNTIME) public static @interface ancestorResized {}
    @Override public void ancestorResized(java.awt.event.HierarchyEvent arg0) { fire(ancestorResized.class, arg0); } 

    
    
}