
package net.ericaro.neoevents.java.awt.event;

//GENERATED DO NOT EDIT

import java.lang.annotation.Annotation;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;

import net.ericaro.neoevents.AbstractEvent;

/**
 *  <p>This is a transparent {@link java.awt.event.HierarchyListener} that uses annotations to convert any objects into
 *  an HierarchyListener. </p>
 * 
 * Annotating methods of any object with the following annotations: 
 *
 * <ul><li>hierarchyChanged</li>
</ul>
 *
 * will call those methods when the corresponding events is fired.
 * 
 * example
 * <p>
 * <pre>
 * public class MyController {
 *     
 *     ...
 *     
 *     Object source;
 * 
 *     ...
 * 
 *     source.addHierarchyListener(new HierarchyListener(this) );
 *     
 *     ...    
 *     
 *     &#64;HierarchyListener.hierarchyChanged
 *     protected void go(){
 *     System.out.println("go! go! go!"); // called when source will trigger the HierarchyListener.hierarchyChanged event
 *     }
 * 
 * }
 * 
 * methods can be either:
 * <ul>
 * <li>without parameters</li>
 * <li>without one parameter of any super type of the corresponding event type</li>
 * </ul>
 * 
 * </pre>
 * 
 * </p>
 * 
 *
 */
public class HierarchyListener extends AbstractEvent implements java.awt.event.HierarchyListener{

    /** Creates an instance of Interface java.awt.event.HierarchyListener that will forward every call to the target's methods annotated with:
     * <ul><li>hierarchyChanged</li>
</ul>
     *
     * @param target the object that will receive events
     */
    public HierarchyListener(Object target) {
        super(target
            ,hierarchyChanged.class

                
        );
    }
    
    
    /** Annotation to mark a method as a target for {@link java.awt.event.HierarchyListener.hierarchyChanged()} calls  */
    @Retention(RetentionPolicy.RUNTIME) public static @interface hierarchyChanged {}
    @Override public void hierarchyChanged(java.awt.event.HierarchyEvent arg0) { fire(hierarchyChanged.class, arg0); } 

    
    
}