
package net.ericaro.neoevents.java.awt.event;

//GENERATED DO NOT EDIT

import java.lang.annotation.Annotation;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;

import net.ericaro.neoevents.AbstractEvent;

/**
 *  <p>This is a transparent {@link java.awt.event.InputMethodListener} that uses annotations to convert any objects into
 *  an InputMethodListener. </p>
 * 
 * Annotating methods of any object with the following annotations: 
 *
 * <ul><li>caretPositionChanged</li>
<li>inputMethodTextChanged</li>
</ul>
 *
 * will call those methods when the corresponding events is fired.
 * 
 * example
 * <p>
 * <pre>
 * public class MyController {
 *     
 *     ...
 *     
 *     Object source;
 * 
 *     ...
 * 
 *     source.addInputMethodListener(new InputMethodListener(this) );
 *     
 *     ...    
 *     
 *     &#64;InputMethodListener.caretPositionChanged
 *     protected void go(){
 *     System.out.println("go! go! go!"); // called when source will trigger the InputMethodListener.caretPositionChanged event
 *     }
 * 
 * }
 * 
 * methods can be either:
 * <ul>
 * <li>without parameters</li>
 * <li>without one parameter of any super type of the corresponding event type</li>
 * </ul>
 * 
 * </pre>
 * 
 * </p>
 * 
 *
 */
public class InputMethodListener extends AbstractEvent implements java.awt.event.InputMethodListener{

    /** Creates an instance of Interface java.awt.event.InputMethodListener that will forward every call to the target's methods annotated with:
     * <ul><li>caretPositionChanged</li>
<li>inputMethodTextChanged</li>
</ul>
     *
     * @param target the object that will receive events
     */
    public InputMethodListener(Object target) {
        super(target
            ,caretPositionChanged.class
            ,inputMethodTextChanged.class

                
        );
    }
    
    
    /** Annotation to mark a method as a target for {@link java.awt.event.InputMethodListener.caretPositionChanged()} calls  */
    @Retention(RetentionPolicy.RUNTIME) public static @interface caretPositionChanged {}
    @Override public void caretPositionChanged(java.awt.event.InputMethodEvent arg0) { fire(caretPositionChanged.class, arg0); } 


    /** Annotation to mark a method as a target for {@link java.awt.event.InputMethodListener.inputMethodTextChanged()} calls  */
    @Retention(RetentionPolicy.RUNTIME) public static @interface inputMethodTextChanged {}
    @Override public void inputMethodTextChanged(java.awt.event.InputMethodEvent arg0) { fire(inputMethodTextChanged.class, arg0); } 

    
    
}