
package net.ericaro.neoevents.java.awt.event;

//GENERATED DO NOT EDIT

import java.lang.annotation.Annotation;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;

import net.ericaro.neoevents.AbstractEvent;

/**
 *  <p>This is a transparent {@link java.awt.event.ItemListener} that uses annotations to convert any objects into
 *  an ItemListener. </p>
 * 
 * Annotating methods of any object with the following annotations: 
 *
 * <ul><li>itemStateChanged</li>
</ul>
 *
 * will call those methods when the corresponding events is fired.
 * 
 * example
 * <p>
 * <pre>
 * public class MyController {
 *     
 *     ...
 *     
 *     Object source;
 * 
 *     ...
 * 
 *     source.addItemListener(new ItemListener(this) );
 *     
 *     ...    
 *     
 *     &#64;ItemListener.itemStateChanged
 *     protected void go(){
 *     System.out.println("go! go! go!"); // called when source will trigger the ItemListener.itemStateChanged event
 *     }
 * 
 * }
 * 
 * methods can be either:
 * <ul>
 * <li>without parameters</li>
 * <li>without one parameter of any super type of the corresponding event type</li>
 * </ul>
 * 
 * </pre>
 * 
 * </p>
 * 
 *
 */
public class ItemListener extends AbstractEvent implements java.awt.event.ItemListener{

    /** Creates an instance of Interface java.awt.event.ItemListener that will forward every call to the target's methods annotated with:
     * <ul><li>itemStateChanged</li>
</ul>
     *
     * @param target the object that will receive events
     */
    public ItemListener(Object target) {
        super(target
            ,itemStateChanged.class

                
        );
    }
    
    
    /** Annotation to mark a method as a target for {@link java.awt.event.ItemListener.itemStateChanged()} calls  */
    @Retention(RetentionPolicy.RUNTIME) public static @interface itemStateChanged {}
    @Override public void itemStateChanged(java.awt.event.ItemEvent arg0) { fire(itemStateChanged.class, arg0); } 

    
    
}