
package net.ericaro.neoevents.java.awt.event;

//GENERATED DO NOT EDIT

import java.lang.annotation.Annotation;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;

import net.ericaro.neoevents.AbstractEvent;

/**
 *  <p>This is a transparent {@link java.awt.event.KeyListener} that uses annotations to convert any objects into
 *  an KeyListener. </p>
 * 
 * Annotating methods of any object with the following annotations: 
 *
 * <ul><li>keyPressed</li>
<li>keyReleased</li>
<li>keyTyped</li>
</ul>
 *
 * will call those methods when the corresponding events is fired.
 * 
 * example
 * <p>
 * <pre>
 * public class MyController {
 *     
 *     ...
 *     
 *     Object source;
 * 
 *     ...
 * 
 *     source.addKeyListener(new KeyListener(this) );
 *     
 *     ...    
 *     
 *     &#64;KeyListener.keyPressed
 *     protected void go(){
 *     System.out.println("go! go! go!"); // called when source will trigger the KeyListener.keyPressed event
 *     }
 * 
 * }
 * 
 * methods can be either:
 * <ul>
 * <li>without parameters</li>
 * <li>without one parameter of any super type of the corresponding event type</li>
 * </ul>
 * 
 * </pre>
 * 
 * </p>
 * 
 *
 */
public class KeyListener extends AbstractEvent implements java.awt.event.KeyListener{

    /** Creates an instance of Interface java.awt.event.KeyListener that will forward every call to the target's methods annotated with:
     * <ul><li>keyPressed</li>
<li>keyReleased</li>
<li>keyTyped</li>
</ul>
     *
     * @param target the object that will receive events
     */
    public KeyListener(Object target) {
        super(target
            ,keyPressed.class
            ,keyReleased.class
            ,keyTyped.class

                
        );
    }
    
    
    /** Annotation to mark a method as a target for {@link java.awt.event.KeyListener.keyPressed()} calls  */
    @Retention(RetentionPolicy.RUNTIME) public static @interface keyPressed {}
    @Override public void keyPressed(java.awt.event.KeyEvent arg0) { fire(keyPressed.class, arg0); } 


    /** Annotation to mark a method as a target for {@link java.awt.event.KeyListener.keyReleased()} calls  */
    @Retention(RetentionPolicy.RUNTIME) public static @interface keyReleased {}
    @Override public void keyReleased(java.awt.event.KeyEvent arg0) { fire(keyReleased.class, arg0); } 


    /** Annotation to mark a method as a target for {@link java.awt.event.KeyListener.keyTyped()} calls  */
    @Retention(RetentionPolicy.RUNTIME) public static @interface keyTyped {}
    @Override public void keyTyped(java.awt.event.KeyEvent arg0) { fire(keyTyped.class, arg0); } 

    
    
}