
package net.ericaro.neoevents.java.awt.event;

//GENERATED DO NOT EDIT

import java.lang.annotation.Annotation;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;

import net.ericaro.neoevents.AbstractEvent;

/**
 *  <p>This is a transparent {@link java.awt.event.MouseListener} that uses annotations to convert any objects into
 *  an MouseListener. </p>
 * 
 * Annotating methods of any object with the following annotations: 
 *
 * <ul><li>mouseClicked</li>
<li>mouseEntered</li>
<li>mouseExited</li>
<li>mousePressed</li>
<li>mouseReleased</li>
</ul>
 *
 * will call those methods when the corresponding events is fired.
 * 
 * example
 * <p>
 * <pre>
 * public class MyController {
 *     
 *     ...
 *     
 *     Object source;
 * 
 *     ...
 * 
 *     source.addMouseListener(new MouseListener(this) );
 *     
 *     ...    
 *     
 *     &#64;MouseListener.mouseClicked
 *     protected void go(){
 *     System.out.println("go! go! go!"); // called when source will trigger the MouseListener.mouseClicked event
 *     }
 * 
 * }
 * 
 * methods can be either:
 * <ul>
 * <li>without parameters</li>
 * <li>without one parameter of any super type of the corresponding event type</li>
 * </ul>
 * 
 * </pre>
 * 
 * </p>
 * 
 *
 */
public class MouseListener extends AbstractEvent implements java.awt.event.MouseListener{

    /** Creates an instance of Interface java.awt.event.MouseListener that will forward every call to the target's methods annotated with:
     * <ul><li>mouseClicked</li>
<li>mouseEntered</li>
<li>mouseExited</li>
<li>mousePressed</li>
<li>mouseReleased</li>
</ul>
     *
     * @param target the object that will receive events
     */
    public MouseListener(Object target) {
        super(target
            ,mouseClicked.class
            ,mouseEntered.class
            ,mouseExited.class
            ,mousePressed.class
            ,mouseReleased.class

                
        );
    }
    
    
    /** Annotation to mark a method as a target for {@link java.awt.event.MouseListener.mouseClicked()} calls  */
    @Retention(RetentionPolicy.RUNTIME) public static @interface mouseClicked {}
    @Override public void mouseClicked(java.awt.event.MouseEvent arg0) { fire(mouseClicked.class, arg0); } 


    /** Annotation to mark a method as a target for {@link java.awt.event.MouseListener.mouseEntered()} calls  */
    @Retention(RetentionPolicy.RUNTIME) public static @interface mouseEntered {}
    @Override public void mouseEntered(java.awt.event.MouseEvent arg0) { fire(mouseEntered.class, arg0); } 


    /** Annotation to mark a method as a target for {@link java.awt.event.MouseListener.mouseExited()} calls  */
    @Retention(RetentionPolicy.RUNTIME) public static @interface mouseExited {}
    @Override public void mouseExited(java.awt.event.MouseEvent arg0) { fire(mouseExited.class, arg0); } 


    /** Annotation to mark a method as a target for {@link java.awt.event.MouseListener.mousePressed()} calls  */
    @Retention(RetentionPolicy.RUNTIME) public static @interface mousePressed {}
    @Override public void mousePressed(java.awt.event.MouseEvent arg0) { fire(mousePressed.class, arg0); } 


    /** Annotation to mark a method as a target for {@link java.awt.event.MouseListener.mouseReleased()} calls  */
    @Retention(RetentionPolicy.RUNTIME) public static @interface mouseReleased {}
    @Override public void mouseReleased(java.awt.event.MouseEvent arg0) { fire(mouseReleased.class, arg0); } 

    
    
}