
package net.ericaro.neoevents.java.awt.event;

//GENERATED DO NOT EDIT

import java.lang.annotation.Annotation;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;

import net.ericaro.neoevents.AbstractEvent;

/**
 *  <p>This is a transparent {@link java.awt.event.MouseMotionListener} that uses annotations to convert any objects into
 *  an MouseMotionListener. </p>
 * 
 * Annotating methods of any object with the following annotations: 
 *
 * <ul><li>mouseDragged</li>
<li>mouseMoved</li>
</ul>
 *
 * will call those methods when the corresponding events is fired.
 * 
 * example
 * <p>
 * <pre>
 * public class MyController {
 *     
 *     ...
 *     
 *     Object source;
 * 
 *     ...
 * 
 *     source.addMouseMotionListener(new MouseMotionListener(this) );
 *     
 *     ...    
 *     
 *     &#64;MouseMotionListener.mouseDragged
 *     protected void go(){
 *     System.out.println("go! go! go!"); // called when source will trigger the MouseMotionListener.mouseDragged event
 *     }
 * 
 * }
 * 
 * methods can be either:
 * <ul>
 * <li>without parameters</li>
 * <li>without one parameter of any super type of the corresponding event type</li>
 * </ul>
 * 
 * </pre>
 * 
 * </p>
 * 
 *
 */
public class MouseMotionListener extends AbstractEvent implements java.awt.event.MouseMotionListener{

    /** Creates an instance of Interface java.awt.event.MouseMotionListener that will forward every call to the target's methods annotated with:
     * <ul><li>mouseDragged</li>
<li>mouseMoved</li>
</ul>
     *
     * @param target the object that will receive events
     */
    public MouseMotionListener(Object target) {
        super(target
            ,mouseDragged.class
            ,mouseMoved.class

                
        );
    }
    
    
    /** Annotation to mark a method as a target for {@link java.awt.event.MouseMotionListener.mouseDragged()} calls  */
    @Retention(RetentionPolicy.RUNTIME) public static @interface mouseDragged {}
    @Override public void mouseDragged(java.awt.event.MouseEvent arg0) { fire(mouseDragged.class, arg0); } 


    /** Annotation to mark a method as a target for {@link java.awt.event.MouseMotionListener.mouseMoved()} calls  */
    @Retention(RetentionPolicy.RUNTIME) public static @interface mouseMoved {}
    @Override public void mouseMoved(java.awt.event.MouseEvent arg0) { fire(mouseMoved.class, arg0); } 

    
    
}