
package net.ericaro.neoevents.java.awt.event;

//GENERATED DO NOT EDIT

import java.lang.annotation.Annotation;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;

import net.ericaro.neoevents.AbstractEvent;

/**
 *  <p>This is a transparent {@link java.awt.event.TextListener} that uses annotations to convert any objects into
 *  an TextListener. </p>
 * 
 * Annotating methods of any object with the following annotations: 
 *
 * <ul><li>textValueChanged</li>
</ul>
 *
 * will call those methods when the corresponding events is fired.
 * 
 * example
 * <p>
 * <pre>
 * public class MyController {
 *     
 *     ...
 *     
 *     Object source;
 * 
 *     ...
 * 
 *     source.addTextListener(new TextListener(this) );
 *     
 *     ...    
 *     
 *     &#64;TextListener.textValueChanged
 *     protected void go(){
 *     System.out.println("go! go! go!"); // called when source will trigger the TextListener.textValueChanged event
 *     }
 * 
 * }
 * 
 * methods can be either:
 * <ul>
 * <li>without parameters</li>
 * <li>without one parameter of any super type of the corresponding event type</li>
 * </ul>
 * 
 * </pre>
 * 
 * </p>
 * 
 *
 */
public class TextListener extends AbstractEvent implements java.awt.event.TextListener{

    /** Creates an instance of Interface java.awt.event.TextListener that will forward every call to the target's methods annotated with:
     * <ul><li>textValueChanged</li>
</ul>
     *
     * @param target the object that will receive events
     */
    public TextListener(Object target) {
        super(target
            ,textValueChanged.class

                
        );
    }
    
    
    /** Annotation to mark a method as a target for {@link java.awt.event.TextListener.textValueChanged()} calls  */
    @Retention(RetentionPolicy.RUNTIME) public static @interface textValueChanged {}
    @Override public void textValueChanged(java.awt.event.TextEvent arg0) { fire(textValueChanged.class, arg0); } 

    
    
}