
package net.ericaro.neoevents.java.awt.event;

//GENERATED DO NOT EDIT

import java.lang.annotation.Annotation;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;

import net.ericaro.neoevents.AbstractEvent;

/**
 *  <p>This is a transparent {@link java.awt.event.WindowFocusListener} that uses annotations to convert any objects into
 *  an WindowFocusListener. </p>
 * 
 * Annotating methods of any object with the following annotations: 
 *
 * <ul><li>windowGainedFocus</li>
<li>windowLostFocus</li>
</ul>
 *
 * will call those methods when the corresponding events is fired.
 * 
 * example
 * <p>
 * <pre>
 * public class MyController {
 *     
 *     ...
 *     
 *     Object source;
 * 
 *     ...
 * 
 *     source.addWindowFocusListener(new WindowFocusListener(this) );
 *     
 *     ...    
 *     
 *     &#64;WindowFocusListener.windowGainedFocus
 *     protected void go(){
 *     System.out.println("go! go! go!"); // called when source will trigger the WindowFocusListener.windowGainedFocus event
 *     }
 * 
 * }
 * 
 * methods can be either:
 * <ul>
 * <li>without parameters</li>
 * <li>without one parameter of any super type of the corresponding event type</li>
 * </ul>
 * 
 * </pre>
 * 
 * </p>
 * 
 *
 */
public class WindowFocusListener extends AbstractEvent implements java.awt.event.WindowFocusListener{

    /** Creates an instance of Interface java.awt.event.WindowFocusListener that will forward every call to the target's methods annotated with:
     * <ul><li>windowGainedFocus</li>
<li>windowLostFocus</li>
</ul>
     *
     * @param target the object that will receive events
     */
    public WindowFocusListener(Object target) {
        super(target
            ,windowGainedFocus.class
            ,windowLostFocus.class

                
        );
    }
    
    
    /** Annotation to mark a method as a target for {@link java.awt.event.WindowFocusListener.windowGainedFocus()} calls  */
    @Retention(RetentionPolicy.RUNTIME) public static @interface windowGainedFocus {}
    @Override public void windowGainedFocus(java.awt.event.WindowEvent arg0) { fire(windowGainedFocus.class, arg0); } 


    /** Annotation to mark a method as a target for {@link java.awt.event.WindowFocusListener.windowLostFocus()} calls  */
    @Retention(RetentionPolicy.RUNTIME) public static @interface windowLostFocus {}
    @Override public void windowLostFocus(java.awt.event.WindowEvent arg0) { fire(windowLostFocus.class, arg0); } 

    
    
}