
package net.ericaro.neoevents.java.awt.event;

//GENERATED DO NOT EDIT

import java.lang.annotation.Annotation;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;

import net.ericaro.neoevents.AbstractEvent;

/**
 *  <p>This is a transparent {@link java.awt.event.WindowListener} that uses annotations to convert any objects into
 *  an WindowListener. </p>
 * 
 * Annotating methods of any object with the following annotations: 
 *
 * <ul><li>windowActivated</li>
<li>windowClosed</li>
<li>windowClosing</li>
<li>windowDeactivated</li>
<li>windowDeiconified</li>
<li>windowIconified</li>
<li>windowOpened</li>
</ul>
 *
 * will call those methods when the corresponding events is fired.
 * 
 * example
 * <p>
 * <pre>
 * public class MyController {
 *     
 *     ...
 *     
 *     Object source;
 * 
 *     ...
 * 
 *     source.addWindowListener(new WindowListener(this) );
 *     
 *     ...    
 *     
 *     &#64;WindowListener.windowActivated
 *     protected void go(){
 *     System.out.println("go! go! go!"); // called when source will trigger the WindowListener.windowActivated event
 *     }
 * 
 * }
 * 
 * methods can be either:
 * <ul>
 * <li>without parameters</li>
 * <li>without one parameter of any super type of the corresponding event type</li>
 * </ul>
 * 
 * </pre>
 * 
 * </p>
 * 
 *
 */
public class WindowListener extends AbstractEvent implements java.awt.event.WindowListener{

    /** Creates an instance of Interface java.awt.event.WindowListener that will forward every call to the target's methods annotated with:
     * <ul><li>windowActivated</li>
<li>windowClosed</li>
<li>windowClosing</li>
<li>windowDeactivated</li>
<li>windowDeiconified</li>
<li>windowIconified</li>
<li>windowOpened</li>
</ul>
     *
     * @param target the object that will receive events
     */
    public WindowListener(Object target) {
        super(target
            ,windowActivated.class
            ,windowClosed.class
            ,windowClosing.class
            ,windowDeactivated.class
            ,windowDeiconified.class
            ,windowIconified.class
            ,windowOpened.class

                
        );
    }
    
    
    /** Annotation to mark a method as a target for {@link java.awt.event.WindowListener.windowActivated()} calls  */
    @Retention(RetentionPolicy.RUNTIME) public static @interface windowActivated {}
    @Override public void windowActivated(java.awt.event.WindowEvent arg0) { fire(windowActivated.class, arg0); } 


    /** Annotation to mark a method as a target for {@link java.awt.event.WindowListener.windowClosed()} calls  */
    @Retention(RetentionPolicy.RUNTIME) public static @interface windowClosed {}
    @Override public void windowClosed(java.awt.event.WindowEvent arg0) { fire(windowClosed.class, arg0); } 


    /** Annotation to mark a method as a target for {@link java.awt.event.WindowListener.windowClosing()} calls  */
    @Retention(RetentionPolicy.RUNTIME) public static @interface windowClosing {}
    @Override public void windowClosing(java.awt.event.WindowEvent arg0) { fire(windowClosing.class, arg0); } 


    /** Annotation to mark a method as a target for {@link java.awt.event.WindowListener.windowDeactivated()} calls  */
    @Retention(RetentionPolicy.RUNTIME) public static @interface windowDeactivated {}
    @Override public void windowDeactivated(java.awt.event.WindowEvent arg0) { fire(windowDeactivated.class, arg0); } 


    /** Annotation to mark a method as a target for {@link java.awt.event.WindowListener.windowDeiconified()} calls  */
    @Retention(RetentionPolicy.RUNTIME) public static @interface windowDeiconified {}
    @Override public void windowDeiconified(java.awt.event.WindowEvent arg0) { fire(windowDeiconified.class, arg0); } 


    /** Annotation to mark a method as a target for {@link java.awt.event.WindowListener.windowIconified()} calls  */
    @Retention(RetentionPolicy.RUNTIME) public static @interface windowIconified {}
    @Override public void windowIconified(java.awt.event.WindowEvent arg0) { fire(windowIconified.class, arg0); } 


    /** Annotation to mark a method as a target for {@link java.awt.event.WindowListener.windowOpened()} calls  */
    @Retention(RetentionPolicy.RUNTIME) public static @interface windowOpened {}
    @Override public void windowOpened(java.awt.event.WindowEvent arg0) { fire(windowOpened.class, arg0); } 

    
    
}