
package net.ericaro.neoevents.java.awt.event;

//GENERATED DO NOT EDIT

import java.lang.annotation.Annotation;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;

import net.ericaro.neoevents.AbstractEvent;

/**
 *  <p>This is a transparent {@link java.awt.event.WindowStateListener} that uses annotations to convert any objects into
 *  an WindowStateListener. </p>
 * 
 * Annotating methods of any object with the following annotations: 
 *
 * <ul><li>windowStateChanged</li>
</ul>
 *
 * will call those methods when the corresponding events is fired.
 * 
 * example
 * <p>
 * <pre>
 * public class MyController {
 *     
 *     ...
 *     
 *     Object source;
 * 
 *     ...
 * 
 *     source.addWindowStateListener(new WindowStateListener(this) );
 *     
 *     ...    
 *     
 *     &#64;WindowStateListener.windowStateChanged
 *     protected void go(){
 *     System.out.println("go! go! go!"); // called when source will trigger the WindowStateListener.windowStateChanged event
 *     }
 * 
 * }
 * 
 * methods can be either:
 * <ul>
 * <li>without parameters</li>
 * <li>without one parameter of any super type of the corresponding event type</li>
 * </ul>
 * 
 * </pre>
 * 
 * </p>
 * 
 *
 */
public class WindowStateListener extends AbstractEvent implements java.awt.event.WindowStateListener{

    /** Creates an instance of Interface java.awt.event.WindowStateListener that will forward every call to the target's methods annotated with:
     * <ul><li>windowStateChanged</li>
</ul>
     *
     * @param target the object that will receive events
     */
    public WindowStateListener(Object target) {
        super(target
            ,windowStateChanged.class

                
        );
    }
    
    
    /** Annotation to mark a method as a target for {@link java.awt.event.WindowStateListener.windowStateChanged()} calls  */
    @Retention(RetentionPolicy.RUNTIME) public static @interface windowStateChanged {}
    @Override public void windowStateChanged(java.awt.event.WindowEvent arg0) { fire(windowStateChanged.class, arg0); } 

    
    
}