
package net.ericaro.neoevents.javax.imageio.event;

//GENERATED DO NOT EDIT

import java.lang.annotation.Annotation;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;

import net.ericaro.neoevents.AbstractEvent;

/**
 *  <p>This is a transparent {@link javax.imageio.event.IIOReadProgressListener} that uses annotations to convert any objects into
 *  an IIOReadProgressListener. </p>
 * 
 * Annotating methods of any object with the following annotations: 
 *
 * <ul><li>imageProgress</li>
<li>imageStarted</li>
<li>readAborted</li>
<li>sequenceComplete</li>
<li>sequenceStarted</li>
<li>thumbnailComplete</li>
<li>thumbnailProgress</li>
<li>thumbnailStarted</li>
<li>imageComplete</li>
</ul>
 *
 * will call those methods when the corresponding events is fired.
 * 
 * example
 * <p>
 * <pre>
 * public class MyController {
 *     
 *     ...
 *     
 *     Object source;
 * 
 *     ...
 * 
 *     source.addIIOReadProgressListener(new IIOReadProgressListener(this) );
 *     
 *     ...    
 *     
 *     &#64;IIOReadProgressListener.imageProgress
 *     protected void go(){
 *     System.out.println("go! go! go!"); // called when source will trigger the IIOReadProgressListener.imageProgress event
 *     }
 * 
 * }
 * 
 * methods can be either:
 * <ul>
 * <li>without parameters</li>
 * <li>without one parameter of any super type of the corresponding event type</li>
 * </ul>
 * 
 * </pre>
 * 
 * </p>
 * 
 *
 */
public class IIOReadProgressListener extends AbstractEvent implements javax.imageio.event.IIOReadProgressListener{

    /** Creates an instance of Interface javax.imageio.event.IIOReadProgressListener that will forward every call to the target's methods annotated with:
     * <ul><li>imageProgress</li>
<li>imageStarted</li>
<li>readAborted</li>
<li>sequenceComplete</li>
<li>sequenceStarted</li>
<li>thumbnailComplete</li>
<li>thumbnailProgress</li>
<li>thumbnailStarted</li>
<li>imageComplete</li>
</ul>
     *
     * @param target the object that will receive events
     */
    public IIOReadProgressListener(Object target) {
        super(target
            ,imageProgress.class
            ,imageStarted.class
            ,readAborted.class
            ,sequenceComplete.class
            ,sequenceStarted.class
            ,thumbnailComplete.class
            ,thumbnailProgress.class
            ,thumbnailStarted.class
            ,imageComplete.class

                
        );
    }
    
    
    /** Annotation to mark a method as a target for {@link javax.imageio.event.IIOReadProgressListener.imageProgress()} calls  */
    @Retention(RetentionPolicy.RUNTIME) public static @interface imageProgress {}
    @Override public void imageProgress(javax.imageio.ImageReader arg0, float arg1) { fire(imageProgress.class, arg0, arg1); } 


    /** Annotation to mark a method as a target for {@link javax.imageio.event.IIOReadProgressListener.imageStarted()} calls  */
    @Retention(RetentionPolicy.RUNTIME) public static @interface imageStarted {}
    @Override public void imageStarted(javax.imageio.ImageReader arg0, int arg1) { fire(imageStarted.class, arg0, arg1); } 


    /** Annotation to mark a method as a target for {@link javax.imageio.event.IIOReadProgressListener.readAborted()} calls  */
    @Retention(RetentionPolicy.RUNTIME) public static @interface readAborted {}
    @Override public void readAborted(javax.imageio.ImageReader arg0) { fire(readAborted.class, arg0); } 


    /** Annotation to mark a method as a target for {@link javax.imageio.event.IIOReadProgressListener.sequenceComplete()} calls  */
    @Retention(RetentionPolicy.RUNTIME) public static @interface sequenceComplete {}
    @Override public void sequenceComplete(javax.imageio.ImageReader arg0) { fire(sequenceComplete.class, arg0); } 


    /** Annotation to mark a method as a target for {@link javax.imageio.event.IIOReadProgressListener.sequenceStarted()} calls  */
    @Retention(RetentionPolicy.RUNTIME) public static @interface sequenceStarted {}
    @Override public void sequenceStarted(javax.imageio.ImageReader arg0, int arg1) { fire(sequenceStarted.class, arg0, arg1); } 


    /** Annotation to mark a method as a target for {@link javax.imageio.event.IIOReadProgressListener.thumbnailComplete()} calls  */
    @Retention(RetentionPolicy.RUNTIME) public static @interface thumbnailComplete {}
    @Override public void thumbnailComplete(javax.imageio.ImageReader arg0) { fire(thumbnailComplete.class, arg0); } 


    /** Annotation to mark a method as a target for {@link javax.imageio.event.IIOReadProgressListener.thumbnailProgress()} calls  */
    @Retention(RetentionPolicy.RUNTIME) public static @interface thumbnailProgress {}
    @Override public void thumbnailProgress(javax.imageio.ImageReader arg0, float arg1) { fire(thumbnailProgress.class, arg0, arg1); } 


    /** Annotation to mark a method as a target for {@link javax.imageio.event.IIOReadProgressListener.thumbnailStarted()} calls  */
    @Retention(RetentionPolicy.RUNTIME) public static @interface thumbnailStarted {}
    @Override public void thumbnailStarted(javax.imageio.ImageReader arg0, int arg1, int arg2) { fire(thumbnailStarted.class, arg0, arg1, arg2); } 


    /** Annotation to mark a method as a target for {@link javax.imageio.event.IIOReadProgressListener.imageComplete()} calls  */
    @Retention(RetentionPolicy.RUNTIME) public static @interface imageComplete {}
    @Override public void imageComplete(javax.imageio.ImageReader arg0) { fire(imageComplete.class, arg0); } 

    
    
}