
package net.ericaro.neoevents.javax.imageio.event;

//GENERATED DO NOT EDIT

import java.lang.annotation.Annotation;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;

import net.ericaro.neoevents.AbstractEvent;

/**
 *  <p>This is a transparent {@link javax.imageio.event.IIOReadUpdateListener} that uses annotations to convert any objects into
 *  an IIOReadUpdateListener. </p>
 * 
 * Annotating methods of any object with the following annotations: 
 *
 * <ul><li>passComplete</li>
<li>passStarted</li>
<li>thumbnailPassComplete</li>
<li>thumbnailPassStarted</li>
<li>thumbnailUpdate</li>
<li>imageUpdate</li>
</ul>
 *
 * will call those methods when the corresponding events is fired.
 * 
 * example
 * <p>
 * <pre>
 * public class MyController {
 *     
 *     ...
 *     
 *     Object source;
 * 
 *     ...
 * 
 *     source.addIIOReadUpdateListener(new IIOReadUpdateListener(this) );
 *     
 *     ...    
 *     
 *     &#64;IIOReadUpdateListener.passComplete
 *     protected void go(){
 *     System.out.println("go! go! go!"); // called when source will trigger the IIOReadUpdateListener.passComplete event
 *     }
 * 
 * }
 * 
 * methods can be either:
 * <ul>
 * <li>without parameters</li>
 * <li>without one parameter of any super type of the corresponding event type</li>
 * </ul>
 * 
 * </pre>
 * 
 * </p>
 * 
 *
 */
public class IIOReadUpdateListener extends AbstractEvent implements javax.imageio.event.IIOReadUpdateListener{

    /** Creates an instance of Interface javax.imageio.event.IIOReadUpdateListener that will forward every call to the target's methods annotated with:
     * <ul><li>passComplete</li>
<li>passStarted</li>
<li>thumbnailPassComplete</li>
<li>thumbnailPassStarted</li>
<li>thumbnailUpdate</li>
<li>imageUpdate</li>
</ul>
     *
     * @param target the object that will receive events
     */
    public IIOReadUpdateListener(Object target) {
        super(target
            ,passComplete.class
            ,passStarted.class
            ,thumbnailPassComplete.class
            ,thumbnailPassStarted.class
            ,thumbnailUpdate.class
            ,imageUpdate.class

                
        );
    }
    
    
    /** Annotation to mark a method as a target for {@link javax.imageio.event.IIOReadUpdateListener.passComplete()} calls  */
    @Retention(RetentionPolicy.RUNTIME) public static @interface passComplete {}
    @Override public void passComplete(javax.imageio.ImageReader arg0, java.awt.image.BufferedImage arg1) { fire(passComplete.class, arg0, arg1); } 


    /** Annotation to mark a method as a target for {@link javax.imageio.event.IIOReadUpdateListener.passStarted()} calls  */
    @Retention(RetentionPolicy.RUNTIME) public static @interface passStarted {}
    @Override public void passStarted(javax.imageio.ImageReader arg0, java.awt.image.BufferedImage arg1, int arg2, int arg3, int arg4, int arg5, int arg6, int arg7, int arg8, int[] arg9) { fire(passStarted.class, arg0, arg1, arg2, arg3, arg4, arg5, arg6, arg7, arg8, arg9); } 


    /** Annotation to mark a method as a target for {@link javax.imageio.event.IIOReadUpdateListener.thumbnailPassComplete()} calls  */
    @Retention(RetentionPolicy.RUNTIME) public static @interface thumbnailPassComplete {}
    @Override public void thumbnailPassComplete(javax.imageio.ImageReader arg0, java.awt.image.BufferedImage arg1) { fire(thumbnailPassComplete.class, arg0, arg1); } 


    /** Annotation to mark a method as a target for {@link javax.imageio.event.IIOReadUpdateListener.thumbnailPassStarted()} calls  */
    @Retention(RetentionPolicy.RUNTIME) public static @interface thumbnailPassStarted {}
    @Override public void thumbnailPassStarted(javax.imageio.ImageReader arg0, java.awt.image.BufferedImage arg1, int arg2, int arg3, int arg4, int arg5, int arg6, int arg7, int arg8, int[] arg9) { fire(thumbnailPassStarted.class, arg0, arg1, arg2, arg3, arg4, arg5, arg6, arg7, arg8, arg9); } 


    /** Annotation to mark a method as a target for {@link javax.imageio.event.IIOReadUpdateListener.thumbnailUpdate()} calls  */
    @Retention(RetentionPolicy.RUNTIME) public static @interface thumbnailUpdate {}
    @Override public void thumbnailUpdate(javax.imageio.ImageReader arg0, java.awt.image.BufferedImage arg1, int arg2, int arg3, int arg4, int arg5, int arg6, int arg7, int[] arg8) { fire(thumbnailUpdate.class, arg0, arg1, arg2, arg3, arg4, arg5, arg6, arg7, arg8); } 


    /** Annotation to mark a method as a target for {@link javax.imageio.event.IIOReadUpdateListener.imageUpdate()} calls  */
    @Retention(RetentionPolicy.RUNTIME) public static @interface imageUpdate {}
    @Override public void imageUpdate(javax.imageio.ImageReader arg0, java.awt.image.BufferedImage arg1, int arg2, int arg3, int arg4, int arg5, int arg6, int arg7, int[] arg8) { fire(imageUpdate.class, arg0, arg1, arg2, arg3, arg4, arg5, arg6, arg7, arg8); } 

    
    
}