
package net.ericaro.neoevents.javax.imageio.event;

//GENERATED DO NOT EDIT

import java.lang.annotation.Annotation;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;

import net.ericaro.neoevents.AbstractEvent;

/**
 *  <p>This is a transparent {@link javax.imageio.event.IIOWriteProgressListener} that uses annotations to convert any objects into
 *  an IIOWriteProgressListener. </p>
 * 
 * Annotating methods of any object with the following annotations: 
 *
 * <ul><li>imageProgress</li>
<li>imageStarted</li>
<li>thumbnailComplete</li>
<li>thumbnailProgress</li>
<li>thumbnailStarted</li>
<li>writeAborted</li>
<li>imageComplete</li>
</ul>
 *
 * will call those methods when the corresponding events is fired.
 * 
 * example
 * <p>
 * <pre>
 * public class MyController {
 *     
 *     ...
 *     
 *     Object source;
 * 
 *     ...
 * 
 *     source.addIIOWriteProgressListener(new IIOWriteProgressListener(this) );
 *     
 *     ...    
 *     
 *     &#64;IIOWriteProgressListener.imageProgress
 *     protected void go(){
 *     System.out.println("go! go! go!"); // called when source will trigger the IIOWriteProgressListener.imageProgress event
 *     }
 * 
 * }
 * 
 * methods can be either:
 * <ul>
 * <li>without parameters</li>
 * <li>without one parameter of any super type of the corresponding event type</li>
 * </ul>
 * 
 * </pre>
 * 
 * </p>
 * 
 *
 */
public class IIOWriteProgressListener extends AbstractEvent implements javax.imageio.event.IIOWriteProgressListener{

    /** Creates an instance of Interface javax.imageio.event.IIOWriteProgressListener that will forward every call to the target's methods annotated with:
     * <ul><li>imageProgress</li>
<li>imageStarted</li>
<li>thumbnailComplete</li>
<li>thumbnailProgress</li>
<li>thumbnailStarted</li>
<li>writeAborted</li>
<li>imageComplete</li>
</ul>
     *
     * @param target the object that will receive events
     */
    public IIOWriteProgressListener(Object target) {
        super(target
            ,imageProgress.class
            ,imageStarted.class
            ,thumbnailComplete.class
            ,thumbnailProgress.class
            ,thumbnailStarted.class
            ,writeAborted.class
            ,imageComplete.class

                
        );
    }
    
    
    /** Annotation to mark a method as a target for {@link javax.imageio.event.IIOWriteProgressListener.imageProgress()} calls  */
    @Retention(RetentionPolicy.RUNTIME) public static @interface imageProgress {}
    @Override public void imageProgress(javax.imageio.ImageWriter arg0, float arg1) { fire(imageProgress.class, arg0, arg1); } 


    /** Annotation to mark a method as a target for {@link javax.imageio.event.IIOWriteProgressListener.imageStarted()} calls  */
    @Retention(RetentionPolicy.RUNTIME) public static @interface imageStarted {}
    @Override public void imageStarted(javax.imageio.ImageWriter arg0, int arg1) { fire(imageStarted.class, arg0, arg1); } 


    /** Annotation to mark a method as a target for {@link javax.imageio.event.IIOWriteProgressListener.thumbnailComplete()} calls  */
    @Retention(RetentionPolicy.RUNTIME) public static @interface thumbnailComplete {}
    @Override public void thumbnailComplete(javax.imageio.ImageWriter arg0) { fire(thumbnailComplete.class, arg0); } 


    /** Annotation to mark a method as a target for {@link javax.imageio.event.IIOWriteProgressListener.thumbnailProgress()} calls  */
    @Retention(RetentionPolicy.RUNTIME) public static @interface thumbnailProgress {}
    @Override public void thumbnailProgress(javax.imageio.ImageWriter arg0, float arg1) { fire(thumbnailProgress.class, arg0, arg1); } 


    /** Annotation to mark a method as a target for {@link javax.imageio.event.IIOWriteProgressListener.thumbnailStarted()} calls  */
    @Retention(RetentionPolicy.RUNTIME) public static @interface thumbnailStarted {}
    @Override public void thumbnailStarted(javax.imageio.ImageWriter arg0, int arg1, int arg2) { fire(thumbnailStarted.class, arg0, arg1, arg2); } 


    /** Annotation to mark a method as a target for {@link javax.imageio.event.IIOWriteProgressListener.writeAborted()} calls  */
    @Retention(RetentionPolicy.RUNTIME) public static @interface writeAborted {}
    @Override public void writeAborted(javax.imageio.ImageWriter arg0) { fire(writeAborted.class, arg0); } 


    /** Annotation to mark a method as a target for {@link javax.imageio.event.IIOWriteProgressListener.imageComplete()} calls  */
    @Retention(RetentionPolicy.RUNTIME) public static @interface imageComplete {}
    @Override public void imageComplete(javax.imageio.ImageWriter arg0) { fire(imageComplete.class, arg0); } 

    
    
}