
package net.ericaro.neoevents.javax.management;

//GENERATED DO NOT EDIT

import java.lang.annotation.Annotation;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;

import net.ericaro.neoevents.AbstractEvent;

/**
 *  <p>This is a transparent {@link javax.management.NotificationListener} that uses annotations to convert any objects into
 *  an NotificationListener. </p>
 * 
 * Annotating methods of any object with the following annotations: 
 *
 * <ul><li>handleNotification</li>
</ul>
 *
 * will call those methods when the corresponding events is fired.
 * 
 * example
 * <p>
 * <pre>
 * public class MyController {
 *     
 *     ...
 *     
 *     Object source;
 * 
 *     ...
 * 
 *     source.addNotificationListener(new NotificationListener(this) );
 *     
 *     ...    
 *     
 *     &#64;NotificationListener.handleNotification
 *     protected void go(){
 *     System.out.println("go! go! go!"); // called when source will trigger the NotificationListener.handleNotification event
 *     }
 * 
 * }
 * 
 * methods can be either:
 * <ul>
 * <li>without parameters</li>
 * <li>without one parameter of any super type of the corresponding event type</li>
 * </ul>
 * 
 * </pre>
 * 
 * </p>
 * 
 *
 */
public class NotificationListener extends AbstractEvent implements javax.management.NotificationListener{

    /** Creates an instance of Interface javax.management.NotificationListener that will forward every call to the target's methods annotated with:
     * <ul><li>handleNotification</li>
</ul>
     *
     * @param target the object that will receive events
     */
    public NotificationListener(Object target) {
        super(target
            ,handleNotification.class

                
        );
    }
    
    
    /** Annotation to mark a method as a target for {@link javax.management.NotificationListener.handleNotification()} calls  */
    @Retention(RetentionPolicy.RUNTIME) public static @interface handleNotification {}
    @Override public void handleNotification(javax.management.Notification arg0, java.lang.Object arg1) { fire(handleNotification.class, arg0, arg1); } 

    
    
}