
package net.ericaro.neoevents.javax.naming.event;

//GENERATED DO NOT EDIT

import java.lang.annotation.Annotation;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;

import net.ericaro.neoevents.AbstractEvent;

/**
 *  <p>This is a transparent {@link javax.naming.event.NamespaceChangeListener} that uses annotations to convert any objects into
 *  an NamespaceChangeListener. </p>
 * 
 * Annotating methods of any object with the following annotations: 
 *
 * <ul><li>objectAdded</li>
<li>objectRemoved</li>
<li>objectRenamed</li>
<li>namingExceptionThrown</li>
</ul>
 *
 * will call those methods when the corresponding events is fired.
 * 
 * example
 * <p>
 * <pre>
 * public class MyController {
 *     
 *     ...
 *     
 *     Object source;
 * 
 *     ...
 * 
 *     source.addNamespaceChangeListener(new NamespaceChangeListener(this) );
 *     
 *     ...    
 *     
 *     &#64;NamespaceChangeListener.objectAdded
 *     protected void go(){
 *     System.out.println("go! go! go!"); // called when source will trigger the NamespaceChangeListener.objectAdded event
 *     }
 * 
 * }
 * 
 * methods can be either:
 * <ul>
 * <li>without parameters</li>
 * <li>without one parameter of any super type of the corresponding event type</li>
 * </ul>
 * 
 * </pre>
 * 
 * </p>
 * 
 *
 */
public class NamespaceChangeListener extends AbstractEvent implements javax.naming.event.NamespaceChangeListener{

    /** Creates an instance of Interface javax.naming.event.NamespaceChangeListener that will forward every call to the target's methods annotated with:
     * <ul><li>objectAdded</li>
<li>objectRemoved</li>
<li>objectRenamed</li>
<li>namingExceptionThrown</li>
</ul>
     *
     * @param target the object that will receive events
     */
    public NamespaceChangeListener(Object target) {
        super(target
            ,objectAdded.class
            ,objectRemoved.class
            ,objectRenamed.class
            ,namingExceptionThrown.class

                
        );
    }
    
    
    /** Annotation to mark a method as a target for {@link javax.naming.event.NamespaceChangeListener.objectAdded()} calls  */
    @Retention(RetentionPolicy.RUNTIME) public static @interface objectAdded {}
    @Override public void objectAdded(javax.naming.event.NamingEvent arg0) { fire(objectAdded.class, arg0); } 


    /** Annotation to mark a method as a target for {@link javax.naming.event.NamespaceChangeListener.objectRemoved()} calls  */
    @Retention(RetentionPolicy.RUNTIME) public static @interface objectRemoved {}
    @Override public void objectRemoved(javax.naming.event.NamingEvent arg0) { fire(objectRemoved.class, arg0); } 


    /** Annotation to mark a method as a target for {@link javax.naming.event.NamespaceChangeListener.objectRenamed()} calls  */
    @Retention(RetentionPolicy.RUNTIME) public static @interface objectRenamed {}
    @Override public void objectRenamed(javax.naming.event.NamingEvent arg0) { fire(objectRenamed.class, arg0); } 


    /** Annotation to mark a method as a target for {@link javax.naming.event.NamespaceChangeListener.namingExceptionThrown()} calls  */
    @Retention(RetentionPolicy.RUNTIME) public static @interface namingExceptionThrown {}
    @Override public void namingExceptionThrown(javax.naming.event.NamingExceptionEvent arg0) { fire(namingExceptionThrown.class, arg0); } 

    
    
}