
package net.ericaro.neoevents.javax.naming.event;

//GENERATED DO NOT EDIT

import java.lang.annotation.Annotation;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;

import net.ericaro.neoevents.AbstractEvent;

/**
 *  <p>This is a transparent {@link javax.naming.event.ObjectChangeListener} that uses annotations to convert any objects into
 *  an ObjectChangeListener. </p>
 * 
 * Annotating methods of any object with the following annotations: 
 *
 * <ul><li>objectChanged</li>
<li>namingExceptionThrown</li>
</ul>
 *
 * will call those methods when the corresponding events is fired.
 * 
 * example
 * <p>
 * <pre>
 * public class MyController {
 *     
 *     ...
 *     
 *     Object source;
 * 
 *     ...
 * 
 *     source.addObjectChangeListener(new ObjectChangeListener(this) );
 *     
 *     ...    
 *     
 *     &#64;ObjectChangeListener.objectChanged
 *     protected void go(){
 *     System.out.println("go! go! go!"); // called when source will trigger the ObjectChangeListener.objectChanged event
 *     }
 * 
 * }
 * 
 * methods can be either:
 * <ul>
 * <li>without parameters</li>
 * <li>without one parameter of any super type of the corresponding event type</li>
 * </ul>
 * 
 * </pre>
 * 
 * </p>
 * 
 *
 */
public class ObjectChangeListener extends AbstractEvent implements javax.naming.event.ObjectChangeListener{

    /** Creates an instance of Interface javax.naming.event.ObjectChangeListener that will forward every call to the target's methods annotated with:
     * <ul><li>objectChanged</li>
<li>namingExceptionThrown</li>
</ul>
     *
     * @param target the object that will receive events
     */
    public ObjectChangeListener(Object target) {
        super(target
            ,objectChanged.class
            ,namingExceptionThrown.class

                
        );
    }
    
    
    /** Annotation to mark a method as a target for {@link javax.naming.event.ObjectChangeListener.objectChanged()} calls  */
    @Retention(RetentionPolicy.RUNTIME) public static @interface objectChanged {}
    @Override public void objectChanged(javax.naming.event.NamingEvent arg0) { fire(objectChanged.class, arg0); } 


    /** Annotation to mark a method as a target for {@link javax.naming.event.ObjectChangeListener.namingExceptionThrown()} calls  */
    @Retention(RetentionPolicy.RUNTIME) public static @interface namingExceptionThrown {}
    @Override public void namingExceptionThrown(javax.naming.event.NamingExceptionEvent arg0) { fire(namingExceptionThrown.class, arg0); } 

    
    
}