
package net.ericaro.neoevents.javax.naming.ldap;

//GENERATED DO NOT EDIT

import java.lang.annotation.Annotation;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;

import net.ericaro.neoevents.AbstractEvent;

/**
 *  <p>This is a transparent {@link javax.naming.ldap.UnsolicitedNotificationListener} that uses annotations to convert any objects into
 *  an UnsolicitedNotificationListener. </p>
 * 
 * Annotating methods of any object with the following annotations: 
 *
 * <ul><li>notificationReceived</li>
<li>namingExceptionThrown</li>
</ul>
 *
 * will call those methods when the corresponding events is fired.
 * 
 * example
 * <p>
 * <pre>
 * public class MyController {
 *     
 *     ...
 *     
 *     Object source;
 * 
 *     ...
 * 
 *     source.addUnsolicitedNotificationListener(new UnsolicitedNotificationListener(this) );
 *     
 *     ...    
 *     
 *     &#64;UnsolicitedNotificationListener.notificationReceived
 *     protected void go(){
 *     System.out.println("go! go! go!"); // called when source will trigger the UnsolicitedNotificationListener.notificationReceived event
 *     }
 * 
 * }
 * 
 * methods can be either:
 * <ul>
 * <li>without parameters</li>
 * <li>without one parameter of any super type of the corresponding event type</li>
 * </ul>
 * 
 * </pre>
 * 
 * </p>
 * 
 *
 */
public class UnsolicitedNotificationListener extends AbstractEvent implements javax.naming.ldap.UnsolicitedNotificationListener{

    /** Creates an instance of Interface javax.naming.ldap.UnsolicitedNotificationListener that will forward every call to the target's methods annotated with:
     * <ul><li>notificationReceived</li>
<li>namingExceptionThrown</li>
</ul>
     *
     * @param target the object that will receive events
     */
    public UnsolicitedNotificationListener(Object target) {
        super(target
            ,notificationReceived.class
            ,namingExceptionThrown.class

                
        );
    }
    
    
    /** Annotation to mark a method as a target for {@link javax.naming.ldap.UnsolicitedNotificationListener.notificationReceived()} calls  */
    @Retention(RetentionPolicy.RUNTIME) public static @interface notificationReceived {}
    @Override public void notificationReceived(javax.naming.ldap.UnsolicitedNotificationEvent arg0) { fire(notificationReceived.class, arg0); } 


    /** Annotation to mark a method as a target for {@link javax.naming.ldap.UnsolicitedNotificationListener.namingExceptionThrown()} calls  */
    @Retention(RetentionPolicy.RUNTIME) public static @interface namingExceptionThrown {}
    @Override public void namingExceptionThrown(javax.naming.event.NamingExceptionEvent arg0) { fire(namingExceptionThrown.class, arg0); } 

    
    
}