
package net.ericaro.neoevents.javax.net.ssl;

//GENERATED DO NOT EDIT

import java.lang.annotation.Annotation;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;

import net.ericaro.neoevents.AbstractEvent;

/**
 *  <p>This is a transparent {@link javax.net.ssl.SSLSessionBindingListener} that uses annotations to convert any objects into
 *  an SSLSessionBindingListener. </p>
 * 
 * Annotating methods of any object with the following annotations: 
 *
 * <ul><li>valueBound</li>
<li>valueUnbound</li>
</ul>
 *
 * will call those methods when the corresponding events is fired.
 * 
 * example
 * <p>
 * <pre>
 * public class MyController {
 *     
 *     ...
 *     
 *     Object source;
 * 
 *     ...
 * 
 *     source.addSSLSessionBindingListener(new SSLSessionBindingListener(this) );
 *     
 *     ...    
 *     
 *     &#64;SSLSessionBindingListener.valueBound
 *     protected void go(){
 *     System.out.println("go! go! go!"); // called when source will trigger the SSLSessionBindingListener.valueBound event
 *     }
 * 
 * }
 * 
 * methods can be either:
 * <ul>
 * <li>without parameters</li>
 * <li>without one parameter of any super type of the corresponding event type</li>
 * </ul>
 * 
 * </pre>
 * 
 * </p>
 * 
 *
 */
public class SSLSessionBindingListener extends AbstractEvent implements javax.net.ssl.SSLSessionBindingListener{

    /** Creates an instance of Interface javax.net.ssl.SSLSessionBindingListener that will forward every call to the target's methods annotated with:
     * <ul><li>valueBound</li>
<li>valueUnbound</li>
</ul>
     *
     * @param target the object that will receive events
     */
    public SSLSessionBindingListener(Object target) {
        super(target
            ,valueBound.class
            ,valueUnbound.class

                
        );
    }
    
    
    /** Annotation to mark a method as a target for {@link javax.net.ssl.SSLSessionBindingListener.valueBound()} calls  */
    @Retention(RetentionPolicy.RUNTIME) public static @interface valueBound {}
    @Override public void valueBound(javax.net.ssl.SSLSessionBindingEvent arg0) { fire(valueBound.class, arg0); } 


    /** Annotation to mark a method as a target for {@link javax.net.ssl.SSLSessionBindingListener.valueUnbound()} calls  */
    @Retention(RetentionPolicy.RUNTIME) public static @interface valueUnbound {}
    @Override public void valueUnbound(javax.net.ssl.SSLSessionBindingEvent arg0) { fire(valueUnbound.class, arg0); } 

    
    
}