
package net.ericaro.neoevents.javax.sql;

//GENERATED DO NOT EDIT

import java.lang.annotation.Annotation;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;

import net.ericaro.neoevents.AbstractEvent;

/**
 *  <p>This is a transparent {@link javax.sql.ConnectionEventListener} that uses annotations to convert any objects into
 *  an ConnectionEventListener. </p>
 * 
 * Annotating methods of any object with the following annotations: 
 *
 * <ul><li>connectionClosed</li>
<li>connectionErrorOccurred</li>
</ul>
 *
 * will call those methods when the corresponding events is fired.
 * 
 * example
 * <p>
 * <pre>
 * public class MyController {
 *     
 *     ...
 *     
 *     Object source;
 * 
 *     ...
 * 
 *     source.addConnectionEventListener(new ConnectionEventListener(this) );
 *     
 *     ...    
 *     
 *     &#64;ConnectionEventListener.connectionClosed
 *     protected void go(){
 *     System.out.println("go! go! go!"); // called when source will trigger the ConnectionEventListener.connectionClosed event
 *     }
 * 
 * }
 * 
 * methods can be either:
 * <ul>
 * <li>without parameters</li>
 * <li>without one parameter of any super type of the corresponding event type</li>
 * </ul>
 * 
 * </pre>
 * 
 * </p>
 * 
 *
 */
public class ConnectionEventListener extends AbstractEvent implements javax.sql.ConnectionEventListener{

    /** Creates an instance of Interface javax.sql.ConnectionEventListener that will forward every call to the target's methods annotated with:
     * <ul><li>connectionClosed</li>
<li>connectionErrorOccurred</li>
</ul>
     *
     * @param target the object that will receive events
     */
    public ConnectionEventListener(Object target) {
        super(target
            ,connectionClosed.class
            ,connectionErrorOccurred.class

                
        );
    }
    
    
    /** Annotation to mark a method as a target for {@link javax.sql.ConnectionEventListener.connectionClosed()} calls  */
    @Retention(RetentionPolicy.RUNTIME) public static @interface connectionClosed {}
    @Override public void connectionClosed(javax.sql.ConnectionEvent arg0) { fire(connectionClosed.class, arg0); } 


    /** Annotation to mark a method as a target for {@link javax.sql.ConnectionEventListener.connectionErrorOccurred()} calls  */
    @Retention(RetentionPolicy.RUNTIME) public static @interface connectionErrorOccurred {}
    @Override public void connectionErrorOccurred(javax.sql.ConnectionEvent arg0) { fire(connectionErrorOccurred.class, arg0); } 

    
    
}