
package net.ericaro.neoevents.javax.sql;

//GENERATED DO NOT EDIT

import java.lang.annotation.Annotation;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;

import net.ericaro.neoevents.AbstractEvent;

/**
 *  <p>This is a transparent {@link javax.sql.RowSetListener} that uses annotations to convert any objects into
 *  an RowSetListener. </p>
 * 
 * Annotating methods of any object with the following annotations: 
 *
 * <ul><li>cursorMoved</li>
<li>rowChanged</li>
<li>rowSetChanged</li>
</ul>
 *
 * will call those methods when the corresponding events is fired.
 * 
 * example
 * <p>
 * <pre>
 * public class MyController {
 *     
 *     ...
 *     
 *     Object source;
 * 
 *     ...
 * 
 *     source.addRowSetListener(new RowSetListener(this) );
 *     
 *     ...    
 *     
 *     &#64;RowSetListener.cursorMoved
 *     protected void go(){
 *     System.out.println("go! go! go!"); // called when source will trigger the RowSetListener.cursorMoved event
 *     }
 * 
 * }
 * 
 * methods can be either:
 * <ul>
 * <li>without parameters</li>
 * <li>without one parameter of any super type of the corresponding event type</li>
 * </ul>
 * 
 * </pre>
 * 
 * </p>
 * 
 *
 */
public class RowSetListener extends AbstractEvent implements javax.sql.RowSetListener{

    /** Creates an instance of Interface javax.sql.RowSetListener that will forward every call to the target's methods annotated with:
     * <ul><li>cursorMoved</li>
<li>rowChanged</li>
<li>rowSetChanged</li>
</ul>
     *
     * @param target the object that will receive events
     */
    public RowSetListener(Object target) {
        super(target
            ,cursorMoved.class
            ,rowChanged.class
            ,rowSetChanged.class

                
        );
    }
    
    
    /** Annotation to mark a method as a target for {@link javax.sql.RowSetListener.cursorMoved()} calls  */
    @Retention(RetentionPolicy.RUNTIME) public static @interface cursorMoved {}
    @Override public void cursorMoved(javax.sql.RowSetEvent arg0) { fire(cursorMoved.class, arg0); } 


    /** Annotation to mark a method as a target for {@link javax.sql.RowSetListener.rowChanged()} calls  */
    @Retention(RetentionPolicy.RUNTIME) public static @interface rowChanged {}
    @Override public void rowChanged(javax.sql.RowSetEvent arg0) { fire(rowChanged.class, arg0); } 


    /** Annotation to mark a method as a target for {@link javax.sql.RowSetListener.rowSetChanged()} calls  */
    @Retention(RetentionPolicy.RUNTIME) public static @interface rowSetChanged {}
    @Override public void rowSetChanged(javax.sql.RowSetEvent arg0) { fire(rowSetChanged.class, arg0); } 

    
    
}