
package net.ericaro.neoevents.javax.sql;

//GENERATED DO NOT EDIT

import java.lang.annotation.Annotation;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;

import net.ericaro.neoevents.AbstractEvent;

/**
 *  <p>This is a transparent {@link javax.sql.StatementEventListener} that uses annotations to convert any objects into
 *  an StatementEventListener. </p>
 * 
 * Annotating methods of any object with the following annotations: 
 *
 * <ul><li>statementClosed</li>
<li>statementErrorOccurred</li>
</ul>
 *
 * will call those methods when the corresponding events is fired.
 * 
 * example
 * <p>
 * <pre>
 * public class MyController {
 *     
 *     ...
 *     
 *     Object source;
 * 
 *     ...
 * 
 *     source.addStatementEventListener(new StatementEventListener(this) );
 *     
 *     ...    
 *     
 *     &#64;StatementEventListener.statementClosed
 *     protected void go(){
 *     System.out.println("go! go! go!"); // called when source will trigger the StatementEventListener.statementClosed event
 *     }
 * 
 * }
 * 
 * methods can be either:
 * <ul>
 * <li>without parameters</li>
 * <li>without one parameter of any super type of the corresponding event type</li>
 * </ul>
 * 
 * </pre>
 * 
 * </p>
 * 
 *
 */
public class StatementEventListener extends AbstractEvent implements javax.sql.StatementEventListener{

    /** Creates an instance of Interface javax.sql.StatementEventListener that will forward every call to the target's methods annotated with:
     * <ul><li>statementClosed</li>
<li>statementErrorOccurred</li>
</ul>
     *
     * @param target the object that will receive events
     */
    public StatementEventListener(Object target) {
        super(target
            ,statementClosed.class
            ,statementErrorOccurred.class

                
        );
    }
    
    
    /** Annotation to mark a method as a target for {@link javax.sql.StatementEventListener.statementClosed()} calls  */
    @Retention(RetentionPolicy.RUNTIME) public static @interface statementClosed {}
    @Override public void statementClosed(javax.sql.StatementEvent arg0) { fire(statementClosed.class, arg0); } 


    /** Annotation to mark a method as a target for {@link javax.sql.StatementEventListener.statementErrorOccurred()} calls  */
    @Retention(RetentionPolicy.RUNTIME) public static @interface statementErrorOccurred {}
    @Override public void statementErrorOccurred(javax.sql.StatementEvent arg0) { fire(statementErrorOccurred.class, arg0); } 

    
    
}