
package net.ericaro.neoevents.javax.swing.event;

//GENERATED DO NOT EDIT

import java.lang.annotation.Annotation;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;

import net.ericaro.neoevents.AbstractEvent;

/**
 *  <p>This is a transparent {@link javax.swing.event.AncestorListener} that uses annotations to convert any objects into
 *  an AncestorListener. </p>
 * 
 * Annotating methods of any object with the following annotations: 
 *
 * <ul><li>ancestorMoved</li>
<li>ancestorAdded</li>
<li>ancestorRemoved</li>
</ul>
 *
 * will call those methods when the corresponding events is fired.
 * 
 * example
 * <p>
 * <pre>
 * public class MyController {
 *     
 *     ...
 *     
 *     Object source;
 * 
 *     ...
 * 
 *     source.addAncestorListener(new AncestorListener(this) );
 *     
 *     ...    
 *     
 *     &#64;AncestorListener.ancestorMoved
 *     protected void go(){
 *     System.out.println("go! go! go!"); // called when source will trigger the AncestorListener.ancestorMoved event
 *     }
 * 
 * }
 * 
 * methods can be either:
 * <ul>
 * <li>without parameters</li>
 * <li>without one parameter of any super type of the corresponding event type</li>
 * </ul>
 * 
 * </pre>
 * 
 * </p>
 * 
 *
 */
public class AncestorListener extends AbstractEvent implements javax.swing.event.AncestorListener{

    /** Creates an instance of Interface javax.swing.event.AncestorListener that will forward every call to the target's methods annotated with:
     * <ul><li>ancestorMoved</li>
<li>ancestorAdded</li>
<li>ancestorRemoved</li>
</ul>
     *
     * @param target the object that will receive events
     */
    public AncestorListener(Object target) {
        super(target
            ,ancestorMoved.class
            ,ancestorAdded.class
            ,ancestorRemoved.class

                
        );
    }
    
    
    /** Annotation to mark a method as a target for {@link javax.swing.event.AncestorListener.ancestorMoved()} calls  */
    @Retention(RetentionPolicy.RUNTIME) public static @interface ancestorMoved {}
    @Override public void ancestorMoved(javax.swing.event.AncestorEvent arg0) { fire(ancestorMoved.class, arg0); } 


    /** Annotation to mark a method as a target for {@link javax.swing.event.AncestorListener.ancestorAdded()} calls  */
    @Retention(RetentionPolicy.RUNTIME) public static @interface ancestorAdded {}
    @Override public void ancestorAdded(javax.swing.event.AncestorEvent arg0) { fire(ancestorAdded.class, arg0); } 


    /** Annotation to mark a method as a target for {@link javax.swing.event.AncestorListener.ancestorRemoved()} calls  */
    @Retention(RetentionPolicy.RUNTIME) public static @interface ancestorRemoved {}
    @Override public void ancestorRemoved(javax.swing.event.AncestorEvent arg0) { fire(ancestorRemoved.class, arg0); } 

    
    
}