
package net.ericaro.neoevents.javax.swing.event;

//GENERATED DO NOT EDIT

import java.lang.annotation.Annotation;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;

import net.ericaro.neoevents.AbstractEvent;

/**
 *  <p>This is a transparent {@link javax.swing.event.DocumentListener} that uses annotations to convert any objects into
 *  an DocumentListener. </p>
 * 
 * Annotating methods of any object with the following annotations: 
 *
 * <ul><li>insertUpdate</li>
<li>removeUpdate</li>
<li>changedUpdate</li>
</ul>
 *
 * will call those methods when the corresponding events is fired.
 * 
 * example
 * <p>
 * <pre>
 * public class MyController {
 *     
 *     ...
 *     
 *     Object source;
 * 
 *     ...
 * 
 *     source.addDocumentListener(new DocumentListener(this) );
 *     
 *     ...    
 *     
 *     &#64;DocumentListener.insertUpdate
 *     protected void go(){
 *     System.out.println("go! go! go!"); // called when source will trigger the DocumentListener.insertUpdate event
 *     }
 * 
 * }
 * 
 * methods can be either:
 * <ul>
 * <li>without parameters</li>
 * <li>without one parameter of any super type of the corresponding event type</li>
 * </ul>
 * 
 * </pre>
 * 
 * </p>
 * 
 *
 */
public class DocumentListener extends AbstractEvent implements javax.swing.event.DocumentListener{

    /** Creates an instance of Interface javax.swing.event.DocumentListener that will forward every call to the target's methods annotated with:
     * <ul><li>insertUpdate</li>
<li>removeUpdate</li>
<li>changedUpdate</li>
</ul>
     *
     * @param target the object that will receive events
     */
    public DocumentListener(Object target) {
        super(target
            ,insertUpdate.class
            ,removeUpdate.class
            ,changedUpdate.class

                
        );
    }
    
    
    /** Annotation to mark a method as a target for {@link javax.swing.event.DocumentListener.insertUpdate()} calls  */
    @Retention(RetentionPolicy.RUNTIME) public static @interface insertUpdate {}
    @Override public void insertUpdate(javax.swing.event.DocumentEvent arg0) { fire(insertUpdate.class, arg0); } 


    /** Annotation to mark a method as a target for {@link javax.swing.event.DocumentListener.removeUpdate()} calls  */
    @Retention(RetentionPolicy.RUNTIME) public static @interface removeUpdate {}
    @Override public void removeUpdate(javax.swing.event.DocumentEvent arg0) { fire(removeUpdate.class, arg0); } 


    /** Annotation to mark a method as a target for {@link javax.swing.event.DocumentListener.changedUpdate()} calls  */
    @Retention(RetentionPolicy.RUNTIME) public static @interface changedUpdate {}
    @Override public void changedUpdate(javax.swing.event.DocumentEvent arg0) { fire(changedUpdate.class, arg0); } 

    
    
}