
package net.ericaro.neoevents.javax.swing.event;

//GENERATED DO NOT EDIT

import java.lang.annotation.Annotation;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;

import net.ericaro.neoevents.AbstractEvent;

/**
 *  <p>This is a transparent {@link javax.swing.event.ListDataListener} that uses annotations to convert any objects into
 *  an ListDataListener. </p>
 * 
 * Annotating methods of any object with the following annotations: 
 *
 * <ul><li>contentsChanged</li>
<li>intervalAdded</li>
<li>intervalRemoved</li>
</ul>
 *
 * will call those methods when the corresponding events is fired.
 * 
 * example
 * <p>
 * <pre>
 * public class MyController {
 *     
 *     ...
 *     
 *     Object source;
 * 
 *     ...
 * 
 *     source.addListDataListener(new ListDataListener(this) );
 *     
 *     ...    
 *     
 *     &#64;ListDataListener.contentsChanged
 *     protected void go(){
 *     System.out.println("go! go! go!"); // called when source will trigger the ListDataListener.contentsChanged event
 *     }
 * 
 * }
 * 
 * methods can be either:
 * <ul>
 * <li>without parameters</li>
 * <li>without one parameter of any super type of the corresponding event type</li>
 * </ul>
 * 
 * </pre>
 * 
 * </p>
 * 
 *
 */
public class ListDataListener extends AbstractEvent implements javax.swing.event.ListDataListener{

    /** Creates an instance of Interface javax.swing.event.ListDataListener that will forward every call to the target's methods annotated with:
     * <ul><li>contentsChanged</li>
<li>intervalAdded</li>
<li>intervalRemoved</li>
</ul>
     *
     * @param target the object that will receive events
     */
    public ListDataListener(Object target) {
        super(target
            ,contentsChanged.class
            ,intervalAdded.class
            ,intervalRemoved.class

                
        );
    }
    
    
    /** Annotation to mark a method as a target for {@link javax.swing.event.ListDataListener.contentsChanged()} calls  */
    @Retention(RetentionPolicy.RUNTIME) public static @interface contentsChanged {}
    @Override public void contentsChanged(javax.swing.event.ListDataEvent arg0) { fire(contentsChanged.class, arg0); } 


    /** Annotation to mark a method as a target for {@link javax.swing.event.ListDataListener.intervalAdded()} calls  */
    @Retention(RetentionPolicy.RUNTIME) public static @interface intervalAdded {}
    @Override public void intervalAdded(javax.swing.event.ListDataEvent arg0) { fire(intervalAdded.class, arg0); } 


    /** Annotation to mark a method as a target for {@link javax.swing.event.ListDataListener.intervalRemoved()} calls  */
    @Retention(RetentionPolicy.RUNTIME) public static @interface intervalRemoved {}
    @Override public void intervalRemoved(javax.swing.event.ListDataEvent arg0) { fire(intervalRemoved.class, arg0); } 

    
    
}