
package net.ericaro.neoevents.javax.swing.event;

//GENERATED DO NOT EDIT

import java.lang.annotation.Annotation;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;

import net.ericaro.neoevents.AbstractEvent;

/**
 *  <p>This is a transparent {@link javax.swing.event.MenuListener} that uses annotations to convert any objects into
 *  an MenuListener. </p>
 * 
 * Annotating methods of any object with the following annotations: 
 *
 * <ul><li>menuCanceled</li>
<li>menuDeselected</li>
<li>menuSelected</li>
</ul>
 *
 * will call those methods when the corresponding events is fired.
 * 
 * example
 * <p>
 * <pre>
 * public class MyController {
 *     
 *     ...
 *     
 *     Object source;
 * 
 *     ...
 * 
 *     source.addMenuListener(new MenuListener(this) );
 *     
 *     ...    
 *     
 *     &#64;MenuListener.menuCanceled
 *     protected void go(){
 *     System.out.println("go! go! go!"); // called when source will trigger the MenuListener.menuCanceled event
 *     }
 * 
 * }
 * 
 * methods can be either:
 * <ul>
 * <li>without parameters</li>
 * <li>without one parameter of any super type of the corresponding event type</li>
 * </ul>
 * 
 * </pre>
 * 
 * </p>
 * 
 *
 */
public class MenuListener extends AbstractEvent implements javax.swing.event.MenuListener{

    /** Creates an instance of Interface javax.swing.event.MenuListener that will forward every call to the target's methods annotated with:
     * <ul><li>menuCanceled</li>
<li>menuDeselected</li>
<li>menuSelected</li>
</ul>
     *
     * @param target the object that will receive events
     */
    public MenuListener(Object target) {
        super(target
            ,menuCanceled.class
            ,menuDeselected.class
            ,menuSelected.class

                
        );
    }
    
    
    /** Annotation to mark a method as a target for {@link javax.swing.event.MenuListener.menuCanceled()} calls  */
    @Retention(RetentionPolicy.RUNTIME) public static @interface menuCanceled {}
    @Override public void menuCanceled(javax.swing.event.MenuEvent arg0) { fire(menuCanceled.class, arg0); } 


    /** Annotation to mark a method as a target for {@link javax.swing.event.MenuListener.menuDeselected()} calls  */
    @Retention(RetentionPolicy.RUNTIME) public static @interface menuDeselected {}
    @Override public void menuDeselected(javax.swing.event.MenuEvent arg0) { fire(menuDeselected.class, arg0); } 


    /** Annotation to mark a method as a target for {@link javax.swing.event.MenuListener.menuSelected()} calls  */
    @Retention(RetentionPolicy.RUNTIME) public static @interface menuSelected {}
    @Override public void menuSelected(javax.swing.event.MenuEvent arg0) { fire(menuSelected.class, arg0); } 

    
    
}