
package net.ericaro.neoevents.javax.swing.event;

//GENERATED DO NOT EDIT

import java.lang.annotation.Annotation;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;

import net.ericaro.neoevents.AbstractEvent;

/**
 *  <p>This is a transparent {@link javax.swing.event.MouseInputListener} that uses annotations to convert any objects into
 *  an MouseInputListener. </p>
 * 
 * Annotating methods of any object with the following annotations: 
 *
 * <ul><li>mouseClicked</li>
<li>mouseEntered</li>
<li>mouseExited</li>
<li>mousePressed</li>
<li>mouseReleased</li>
<li>mouseDragged</li>
<li>mouseMoved</li>
</ul>
 *
 * will call those methods when the corresponding events is fired.
 * 
 * example
 * <p>
 * <pre>
 * public class MyController {
 *     
 *     ...
 *     
 *     Object source;
 * 
 *     ...
 * 
 *     source.addMouseInputListener(new MouseInputListener(this) );
 *     
 *     ...    
 *     
 *     &#64;MouseInputListener.mouseClicked
 *     protected void go(){
 *     System.out.println("go! go! go!"); // called when source will trigger the MouseInputListener.mouseClicked event
 *     }
 * 
 * }
 * 
 * methods can be either:
 * <ul>
 * <li>without parameters</li>
 * <li>without one parameter of any super type of the corresponding event type</li>
 * </ul>
 * 
 * </pre>
 * 
 * </p>
 * 
 *
 */
public class MouseInputListener extends AbstractEvent implements javax.swing.event.MouseInputListener{

    /** Creates an instance of Interface javax.swing.event.MouseInputListener that will forward every call to the target's methods annotated with:
     * <ul><li>mouseClicked</li>
<li>mouseEntered</li>
<li>mouseExited</li>
<li>mousePressed</li>
<li>mouseReleased</li>
<li>mouseDragged</li>
<li>mouseMoved</li>
</ul>
     *
     * @param target the object that will receive events
     */
    public MouseInputListener(Object target) {
        super(target
            ,mouseClicked.class
            ,mouseEntered.class
            ,mouseExited.class
            ,mousePressed.class
            ,mouseReleased.class
            ,mouseDragged.class
            ,mouseMoved.class

                
        );
    }
    
    
    /** Annotation to mark a method as a target for {@link javax.swing.event.MouseInputListener.mouseClicked()} calls  */
    @Retention(RetentionPolicy.RUNTIME) public static @interface mouseClicked {}
    @Override public void mouseClicked(java.awt.event.MouseEvent arg0) { fire(mouseClicked.class, arg0); } 


    /** Annotation to mark a method as a target for {@link javax.swing.event.MouseInputListener.mouseEntered()} calls  */
    @Retention(RetentionPolicy.RUNTIME) public static @interface mouseEntered {}
    @Override public void mouseEntered(java.awt.event.MouseEvent arg0) { fire(mouseEntered.class, arg0); } 


    /** Annotation to mark a method as a target for {@link javax.swing.event.MouseInputListener.mouseExited()} calls  */
    @Retention(RetentionPolicy.RUNTIME) public static @interface mouseExited {}
    @Override public void mouseExited(java.awt.event.MouseEvent arg0) { fire(mouseExited.class, arg0); } 


    /** Annotation to mark a method as a target for {@link javax.swing.event.MouseInputListener.mousePressed()} calls  */
    @Retention(RetentionPolicy.RUNTIME) public static @interface mousePressed {}
    @Override public void mousePressed(java.awt.event.MouseEvent arg0) { fire(mousePressed.class, arg0); } 


    /** Annotation to mark a method as a target for {@link javax.swing.event.MouseInputListener.mouseReleased()} calls  */
    @Retention(RetentionPolicy.RUNTIME) public static @interface mouseReleased {}
    @Override public void mouseReleased(java.awt.event.MouseEvent arg0) { fire(mouseReleased.class, arg0); } 


    /** Annotation to mark a method as a target for {@link javax.swing.event.MouseInputListener.mouseDragged()} calls  */
    @Retention(RetentionPolicy.RUNTIME) public static @interface mouseDragged {}
    @Override public void mouseDragged(java.awt.event.MouseEvent arg0) { fire(mouseDragged.class, arg0); } 


    /** Annotation to mark a method as a target for {@link javax.swing.event.MouseInputListener.mouseMoved()} calls  */
    @Retention(RetentionPolicy.RUNTIME) public static @interface mouseMoved {}
    @Override public void mouseMoved(java.awt.event.MouseEvent arg0) { fire(mouseMoved.class, arg0); } 

    
    
}