
package net.ericaro.neoevents.javax.swing.event;

//GENERATED DO NOT EDIT

import java.lang.annotation.Annotation;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;

import net.ericaro.neoevents.AbstractEvent;

/**
 *  <p>This is a transparent {@link javax.swing.event.TreeModelListener} that uses annotations to convert any objects into
 *  an TreeModelListener. </p>
 * 
 * Annotating methods of any object with the following annotations: 
 *
 * <ul><li>treeNodesChanged</li>
<li>treeNodesInserted</li>
<li>treeNodesRemoved</li>
<li>treeStructureChanged</li>
</ul>
 *
 * will call those methods when the corresponding events is fired.
 * 
 * example
 * <p>
 * <pre>
 * public class MyController {
 *     
 *     ...
 *     
 *     Object source;
 * 
 *     ...
 * 
 *     source.addTreeModelListener(new TreeModelListener(this) );
 *     
 *     ...    
 *     
 *     &#64;TreeModelListener.treeNodesChanged
 *     protected void go(){
 *     System.out.println("go! go! go!"); // called when source will trigger the TreeModelListener.treeNodesChanged event
 *     }
 * 
 * }
 * 
 * methods can be either:
 * <ul>
 * <li>without parameters</li>
 * <li>without one parameter of any super type of the corresponding event type</li>
 * </ul>
 * 
 * </pre>
 * 
 * </p>
 * 
 *
 */
public class TreeModelListener extends AbstractEvent implements javax.swing.event.TreeModelListener{

    /** Creates an instance of Interface javax.swing.event.TreeModelListener that will forward every call to the target's methods annotated with:
     * <ul><li>treeNodesChanged</li>
<li>treeNodesInserted</li>
<li>treeNodesRemoved</li>
<li>treeStructureChanged</li>
</ul>
     *
     * @param target the object that will receive events
     */
    public TreeModelListener(Object target) {
        super(target
            ,treeNodesChanged.class
            ,treeNodesInserted.class
            ,treeNodesRemoved.class
            ,treeStructureChanged.class

                
        );
    }
    
    
    /** Annotation to mark a method as a target for {@link javax.swing.event.TreeModelListener.treeNodesChanged()} calls  */
    @Retention(RetentionPolicy.RUNTIME) public static @interface treeNodesChanged {}
    @Override public void treeNodesChanged(javax.swing.event.TreeModelEvent arg0) { fire(treeNodesChanged.class, arg0); } 


    /** Annotation to mark a method as a target for {@link javax.swing.event.TreeModelListener.treeNodesInserted()} calls  */
    @Retention(RetentionPolicy.RUNTIME) public static @interface treeNodesInserted {}
    @Override public void treeNodesInserted(javax.swing.event.TreeModelEvent arg0) { fire(treeNodesInserted.class, arg0); } 


    /** Annotation to mark a method as a target for {@link javax.swing.event.TreeModelListener.treeNodesRemoved()} calls  */
    @Retention(RetentionPolicy.RUNTIME) public static @interface treeNodesRemoved {}
    @Override public void treeNodesRemoved(javax.swing.event.TreeModelEvent arg0) { fire(treeNodesRemoved.class, arg0); } 


    /** Annotation to mark a method as a target for {@link javax.swing.event.TreeModelListener.treeStructureChanged()} calls  */
    @Retention(RetentionPolicy.RUNTIME) public static @interface treeStructureChanged {}
    @Override public void treeStructureChanged(javax.swing.event.TreeModelEvent arg0) { fire(treeStructureChanged.class, arg0); } 

    
    
}